<?php $__env->startSection('title', 'Sejarah'); ?>


<?php $__env->startSection('content'); ?>
<br><br>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => 'Sejarah  '.e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia').'','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'Sejarah Singkat']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        

        <!-- Konten Teks -->
        <div data-aos="fade-up" class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px]">
            <p class="text-justify" style="font-size: 14px;">

Awal berdirinya Sekolah Tinggi Ilmu Kesehatan Kepanjen (STIKES Kepanjen) dimulai dari pengembangan Sekolah Perawat Kesehatan (SPK) Kepanjen. SPK Kepanjen berdiri pada 1 Oktober 1985 yang diawali dari kelas Ekstensi SPK Depkes Celaket Malang yang penyelenggaraannya dibawah pembinaan Rumah Sakit Umum Kanjuruhan Kepanjen, sehingga fasilitas, tenaga, maupun sarana dan prasarana penunjangnya dibantu oleh Rumah Sakit Umum Kanjuruhan Kepanjen.

SPK Kepanjen secara resmi mendapatkan perijinan operasionalnya dari Menteri Kesehatan RI Nomor: 111/Kep/DIKNAKES/VII/88 dan Surat Keputusan Bupati Dati II Malang, Nomor: 151/1987. Berkembangnya SPK dari tahun 1985 sampai 1998 dicapai tidak lepas dari peranan dan tugas Ketua SPK, pembinaan dari Bapak Bupati Malang dan Kanwil Depkes Propinsi Jawa Timur. SPK Kepanjen mengalami beberapa pergantian kepemimpinan antara lain selaku Ketua Sekolah adalah dr. Ibnu Fajar (1985-1989), dr. Tuti Hariyanto, MARS (1989-1992), dr. Susilowati (1992-1998). Dengan dituntutnya perkembangan pendidikan tenaga kesehatan yang menuntut peningkatan jenjang pendidikan bagi tenaga profesi keperawatan maka atas dasar persyaratan akreditasi pada tahun 1998 status SPK Kepanjen telah menjadi Akademi Keperawatan Kabupaten Malang, berdasarkan Surat Keputusan Ketua Pusat Pendidikan Tenaga Kesehatan Republik Indonesia Nomor: HK.00.06.1.3.5641 tanggal 23 Oktober 1998 dengan status kelembagaan pendidikan dibawah pembinaan Pemerintah Kabupaten Malang yang dipimpin oleh Drs. Driatmojo, Bsc., MBA, MM (1998-2001), Yudiono, S.Kp., M.Kes. (2001-2008), Wiwit Kurniawati, M.Kep., Sp.Mat. (2008-20010), dan H. dr. Abdurrachman, M.Kes. (2010-sekarang).

Berdasarkan SK Mendiknas No. 259/D/O/2008 tanggal 23 Desember 2008, AKPER Kabupaten Malang berubah menjadi Sekolah Tinggi Ilmu Kesehatan (STIKES) Kepanjen yang diresmikan oleh Bapak Bupati Malang tanggal 25 Juli 2009. Saat ini STIKES Kepanjen mempunyai 2 Program Studi yaitu S1 Keperawatan dan DIII Keperawatan.
                
            </p>

        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">
                SEGERA DAFTAR
                </h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
            Bergabunglah bersama  <?php echo e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia'); ?> dan Bangun Wawasan, Bentuk Karakter, Jadilah Pembawa Perubahan!
        </p>
            <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/pendaftaran']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>DAFTAR SEKARANG <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH D:\K2\Template Migrasi\resources\views/Frontend/sejarah.blade.php ENDPATH**/ ?>