<?php $__env->startSection('title', 'Sejarah'); ?>


<?php $__env->startSection('content'); ?>
<br><br>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => 'Sejarah  '.e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia').'','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'Sejarah Singkat']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        

        <!-- Konten Teks -->
        <div data-aos="fade-up" class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px]">
            <p>
            Sekolah Tinggi Ilmu Tarbiyah Nahdatul ‘Ulama Al Farabi Pangandaran adalah lembaga pendidikan Tinggi atau Perguruan Tinggi yang sudah resmi berdiri sejak tahun 2014 dengan nomor SK. KEMENAG RI No. 7052. Dengan ini, STIT NU Al Farabi berani mengibarkan bendera sebagai perguruan tinggi yang pertama resmi di Kab. Pangandaran. STIT NU Al Farabi memunyai dua jurusan, yaitu:
                <ul>1. Manajemen Pendidikan Islam</ul>
                <ul>2. Pendidikan Islam Anak Usia Dini </ul>
            <br><br>
            Di Kab. Pangandaran, dulu Ciamis, K. H. Ahmad Tajudin mendirikan pesantren yang dinamai dengan Riyadusharfi Wal Mantiq. Pesantren ini adalah pesantren terbesar dan tertua di Kab. Pangandaran dengan lulusan yang tersebar diseluruh pelosok negeri. K. H. Ahamd Tajudin sebagai sosok yang visioner, beliau mampu membaca jaman dan mengisi jaman dengan pemikiran yang tepat daya dan tepat guna, walau memang pada waktu itu pemikiran untuk mendirikan perguruan tinggi tidak serta merta direalisasikan dan baru diwujudkan tahun 2014 oleh keluarga dan satri-santrinya.
            <br><br>
            Sekolah Tinggi Ilmu Tarbiyah Nahdlatul Ulama Al Farabi Pangandaran berkoordinasi dengan Nahdlatul Ulama dalam pengembangan perguruan tinggi. Sebagai ormas islam yang moderat dan mengakar di kalangan masyarakat Pangandaran, tentu perguruan tinggi ini lahir dari pemikiran masyarakat untuk masyarakat. Bagaimana warga Nahdliyin mempunyai wadah untuk mempelajari ilmu agama dan sains secara bersamaan, disitulah Al Farabi bersinerg dengan Nahdaltul Ulama.
            <br><br>   
            Kabupaten Pangandaran sebagai kabupeten baru di Jawa Barat tentu harus diisi oleh orang-orang yang unggul dari segi ilmu pengetahuan dan kuat secara spiritual. Sekolah Tinggi Ilmu Tarbiah Nahdaul ‘Ulama Al Farabi Pangandaran dengan program studi Manajemen Pendidikan Islam dan Pendidikan Islam
            </p>

        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">
                SEGERA DAFTAR
                </h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
            Bergabunglah bersama  <?php echo e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia'); ?> dan Bangun Wawasan, Bentuk Karakter, Jadilah Pembawa Perubahan!
        </p>
            <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/pendaftaran']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>DAFTAR SEKARANG <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /home/u645251767/domains/stit-alfarabi.info/ALFARABI/resources/views/Frontend/sejarah.blade.php ENDPATH**/ ?>