<!DOCTYPE html>
<html lang="id">

<head>
    <!-- Meta tags -->
    <meta charset="utf-8">
    <meta name="description" content="Institut Elkatarie (UNTAG SAMARINDA) adalah perguruan tinggi berbasis nilai-nilai Islami yang berlokasi di Kota Samarinda. UNTAG SAMARINDA menawarkan berbagai program studi unggulan jenjang S1, seperti Ilmu Hukum, Kesehatan Masyarakat, Psikologi, Sistem Informasi, dan Teknik Informatika. Dengan biaya kuliah yang terjangkau, UNTAG SAMARINDA menjadi pilihan tepat bagi calon mahasiswa yang mencari pendidikan berkualitas, lingkungan akademik yang mendukung, serta pengembangan karakter islami. Dapatkan pengalaman belajar yang modern, relevan dengan kebutuhan dunia kerja, dan bernilai keislaman di UNTAG SAMARINDA.">
    <meta name="keywords" content="edunitas, Kelas karyawan, Kuliah karyawan, UNTAG SAMARINDA, kampus UNTAG SAMARINDA , biaya kuliah kampus Institut Elkatarie , biaya kuliah, kelas sabtu, akreditasi Institut Elkatarie, kelas karyawan terjangkau Samarinda , S1 Ilmu Hukum , S1 Kesehatan Masyarakat, S1 Psikologi, S1 Sistem Informasi, S1 Teknik Informatika, kampus murah Di Samarinda , kampus Di Samarinda , Institut Elkatarie, biaya kuliah, kelas sabtu, akreditasi UNTAG SAMARINDA ,
     Kampus Kelas Karyawan Di Samarinda , Kuliah Sambil Kerja Di Samarinda , Universitas Terbaik di Samarinda  untuk Karyawan, Biaya Kuliah Terjangkau di Samarinda , Universitas Kelas Sabtu Minggu Di Samarinda , Akreditasi Universitas Di Samarinda ,Perguruan Tinggi Swasta Murah di Samarinda , Program S1 Ilmu Hukum, Program S1 Kesehatan Masyarakat , Program S1 Psikologi , Program S1 Sistem Informasi , Program S1 Teknik Informatika ,  Kampus Swasta Terbaik Samarinda , Universitas Murah  Di Samarinda  terakreditasi Baik,
     Kampus Terjangkau di Samarinda  untuk Karyawan, , Kuliah dengan Biaya Murah di Samarinda  , Universitas dengan Kelas Online Samarinda , Kampus Swasta Kelas Sabtu Minggu di Samarinda , Biaya Kuliah  Sarjana Murah di Samarinda , Biaya Kuliah S1 Murah di Samarinda  , Kampus dengan Program Studi Lengkap di Samarinda " />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    <!--ADS GSC-->

    
    
    <title>Institut Elkatarie (Kelas Karyawan)</title>
    <meta property="og:title" content="Institut Elkatarie (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="Institut Elkatarie (Kelas Karyawan)">
    <meta property="og:image" content="https://UNTAG SAMARINDA.info/images/background/hero1.png">
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description" content="Institut Elkatarie (UNTAG SAMARINDA) di Kota Samarinda menawarkan program S1 Ilmu Hukum, Kesehatan Masyarakat, Psikologi, Sistem Informasi, dan Teknik Informatika dengan biaya kuliah terjangkau. Pilihan tepat untuk pendidikan berkualitas berbasis nilai-nilai Islami.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="Institut Elkatarie (Kelas Karyawan)">
    <meta name="twitter:description" content="Institut Elkatarie (UNTAG SAMARINDA) di Kota Samarinda menyediakan program Kelas Karyawan dengan biaya kuliah terjangkau untuk jenjang S1 Ilmu Hukum, Kesehatan Masyarakat, Psikologi, Sistem Informasi, dan Teknik Informatika. Dirancang khusus bagi pekerja dan profesional yang ingin melanjutkan pendidikan tanpa mengganggu aktivitas kerja, UNTAG SAMARINDA menawarkan jadwal fleksibel, suasana akademik islami, serta kurikulum yang relevan dengan kebutuhan dunia kerja. Raih gelar sarjana sambil tetap produktif bersama UNTAG SAMARINDA Kelas Karyawan!" />
    <meta name="twitter:domain" content="   ">
    <meta name="twitter:image:src" content="https://UNTAG SAMARINDA.info/images/background/hero1.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="Institut Elkatarie | Kuliah Karyawan (K2)" />

    <link rel="apple-touch-icon" sizes="57x57" href="/images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="/images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="/images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="/images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="/images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="/images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"  href="/images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="/images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/images/favicons/favicon-16x16.png">
    <link rel="manifest" href="/images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="/images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">
    


    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@400;600&family=DM+Sans:wght@400;700&display=swap"
        rel="stylesheet">
    <link href="./css/app.css" rel="stylesheet">
    <link href="<?php echo e(asset('css/app.css')); ?>" rel="stylesheet">
    
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css" />

    
    <?php echo $__env->yieldPushContent('prpend-style'); ?>
    <?php echo $__env->yieldPushContent('addon-style'); ?>

</head>

<body>

    <div class="bg-gray-50 py-10">
        <div class="container mx-auto max-w-screen-lg bg-white shadow-lg rounded-lg p-8">
            <div class="text-center border-b-4 border-primary pb-4">
                <img class="w-40 mx-auto mb-4" src="<?php echo e(asset('./images/logo/logo1.png')); ?>" alt="Institut Elkatarie Logo">
                <h2 class="text-2xl font-poppins font-bold text-primary">
                    FORMULIR PENDAFTARAN
                    <br>CALON MAHASISWA BARU <?php echo e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia'); ?>

                </h2>
            </div>

            <div class="mt-6">
                <table class="w-full text-sm font-dmsans text-primary">
                    <!-- Nomor Pendaftaran -->
                    <tr>
                        <td class="py-2 font-medium">Nomor Pendaftaran</td>
                        <td>:</td>
                        <td class="text-accent font-semibold">PO_<?php echo e($data->daftar_id); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Perguruan Tinggi</td>
                        <td>:</td>
                        <td><?php echo e($data->kampus); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Jurusan</td>
                        <td>:</td>
                        <td><?php echo e($data->jurusan); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Wawancara Via</td>
                        <td>:</td>
                        <td><?php echo e($data->no_hp); ?></td>
                    </tr>
                </table>
            </div>

            <div class="mt-8">
                <h3 class="text-lg font-semibold text-primary border-b pb-2">DATA PRIBADI</h3>
                <table class="w-full mt-4 text-sm font-dmsans text-primary">
                    <tr>
                        <td class="py-2 font-medium">Nama</td>
                        <td>:</td>
                        <td class="text-accent font-semibold"><?php echo e($data->nama_leng); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Jenis Kelamin</td>
                        <td>:</td>
                        <td><?php echo e($data->j_kel == 'L' ? 'Laki-laki' : 'Perempuan'); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Tempat Lahir</td>
                        <td>:</td>
                        <td><?php echo e($data->tmpt_lahir); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Tanggal Lahir</td>
                        <td>:</td>
                        <td><?php echo e($data->tgl_lahir); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Nama Ibu Kandung</td>
                        <td>:</td>
                        <td><?php echo e($data->ibu); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Alamat Surat/Rumah</td>
                        <td>:</td>
                        <td><?php echo e($data->al_dom); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Nomor Telepon</td>
                        <td>:</td>
                        <td><?php echo e($data->no_hp); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Nomor WhatsApp</td>
                        <td>:</td>
                        <td><?php echo e($data->no_wa); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Email</td>
                        <td>:</td>
                        <td><?php echo e($data->email); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Ukuran Almamater</td>
                        <td>:</td>
                        <td><?php echo e($data->jaket); ?></td>
                    </tr>
                </table>
            </div>

            <div class="mt-8">
                <h3 class="text-lg font-semibold text-primary border-b pb-2">DATA PENDIDIKAN</h3>
                <table class="w-full mt-4 text-sm font-dmsans text-primary">
                    <tr>
                        <td class="py-2 font-medium">Asal Lulusan</td>
                        <td>:</td>
                        <td><?php echo e($data->lulusan); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Nama Sekolah</td>
                        <td>:</td>
                        <td><?php echo e($data->sekolah); ?></td>
                    </tr>
                </table>
            </div>

            <div class="mt-8">
                <h3 class="text-lg font-semibold text-primary border-b pb-2">DATA PEKERJAAN</h3>
                <table class="w-full mt-4 text-sm font-dmsans text-primary">
                    <tr>
                        <td class="py-2 font-medium">Nama Pekerjaan</td>
                        <td>:</td>
                        <td><?php echo e($data->kerja); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Jabatan</td>
                        <td>:</td>
                        <td><?php echo e($data->jabatan); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Alamat Pekerjaan</td>
                        <td>:</td>
                        <td><?php echo e($data->al_kerja); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Telepon Kantor</td>
                        <td>:</td>
                        <td><?php echo e($data->no_kantor); ?></td>
                    </tr>
                </table>
            </div>

            <div class="flex justify-between items-center mt-12">
                <div>
                    <p class="font-medium"><?php echo e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia'); ?></p>
                    <img class="w-24 mt-2" src="<?php echo e(asset('images/ttd_cap_fix.png')); ?>" alt="TTD Cap">
                    <p class="mt-2 font-medium">STAFF PMB</p>
                </div>
                <div>
                    <p><?php echo e(date('d-m-Y')); ?></p>
                    <p>Calon Mahasiswa,</p>
                    <br><br><br>
                    <p class="font-semibold text-accent"><?php echo e(strtoupper($data->nama_leng)); ?></p>
                </div>
            </div>

            <div class="text-center mt-8">
                <button id="printpagebutton" onclick="printpage()"  style="color:#fff"
                    class="px-4 py-2 bg-primary  rounded-md hover:bg-accent">
                    Cetak
                </button>
            </div>
        </div>
    </div>

    <script>
        function printpage() {
            const printButton = document.getElementById("printpagebutton");
            printButton.style.visibility = 'hidden';
            window.print();
            printButton.style.visibility = 'visible';
        }
    </script>

    
    <?php echo $__env->yieldPushContent('prpend-script'); ?>
    <?php echo $__env->yieldPushContent('addon-script'); ?>

    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.js"></script>
    <script src="./js/app.js"></script>
    <script src="<?php echo e(asset('./js/app.js')); ?>"></script>
</body>

</html>
<?php /**PATH /home/u768956174/domains/institut-elkatarie.info/INSTITA/resources/views/Frontend/cetak.blade.php ENDPATH**/ ?>