-- MySQL dump 10.13  Distrib 8.0.40, for Win64 (x86_64)
--
-- Host: 127.0.0.1    Database: u142502046_unpand
-- ------------------------------------------------------
-- Server version	8.4.3

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!50503 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `beranda`
--

DROP TABLE IF EXISTS `beranda`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `beranda` (
  `beranda_id` int NOT NULL AUTO_INCREMENT,
  `page_id` int NOT NULL,
  `urut` int NOT NULL,
  `tipe` varchar(15) NOT NULL,
  `active` enum('1','0') NOT NULL,
  PRIMARY KEY (`beranda_id`)
) ENGINE=InnoDB AUTO_INCREMENT=11 DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `beranda`
--

LOCK TABLES `beranda` WRITE;
/*!40000 ALTER TABLE `beranda` DISABLE KEYS */;
INSERT INTO `beranda` VALUES (3,16,1,'slide','1'),(4,15,1,'posisi1','1'),(8,27,2,'posisi2','1'),(9,28,3,'posisi2','1');
/*!40000 ALTER TABLE `beranda` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `berita`
--

DROP TABLE IF EXISTS `berita`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `berita` (
  `id_berita` int NOT NULL AUTO_INCREMENT,
  `judul` varchar(200) NOT NULL,
  `slug` varchar(200) NOT NULL,
  `ringkasan` varchar(200) NOT NULL,
  `content` longtext NOT NULL,
  `tanggal_berita` date NOT NULL,
  `file_foto` varchar(200) NOT NULL,
  `path` varchar(200) NOT NULL,
  PRIMARY KEY (`id_berita`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `berita`
--

LOCK TABLES `berita` WRITE;
/*!40000 ALTER TABLE `berita` DISABLE KEYS */;
INSERT INTO `berita` VALUES (3,'UTS','uts','Jadwal UTS','','2024-10-15','74Screenshot_20241022_144245_Microsoft 365 (Office).webp','images/berita-terkini/');
/*!40000 ALTER TABLE `berita` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `biaya`
--

DROP TABLE IF EXISTS `biaya`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `biaya` (
  `biaya_id` int NOT NULL AUTO_INCREMENT,
  `kategori` varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL,
  `jurusan` varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL,
  `biaya_awal` int NOT NULL,
  `biaya_spp` int NOT NULL,
  `deskripsi` text,
  PRIMARY KEY (`biaya_id`)
) ENGINE=InnoDB AUTO_INCREMENT=138 DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `biaya`
--

LOCK TABLES `biaya` WRITE;
/*!40000 ALTER TABLE `biaya` DISABLE KEYS */;
INSERT INTO `biaya` VALUES (75,'Sarjana','S1 Bisnis Digital',600000,400000,'<p><strong>Biaya Formulir Rp 150.000</strong></p>\r\n\r\n<p><strong>Biaya awal*Sesuai Tabel (Angs 1 UKT + Biaya Jas Almamater + KTM + PKKMB)</strong></p>\r\n\r\n<p><strong>Biaya Kuliah Dapat Dicicil Sampai Wisuda</strong></p>'),(125,'Ners','Profesi Ners',1250000,1550000,NULL),(132,'Sarjana','S1 Pariwisata',600000,400000,NULL),(133,'Sarjana','S1 Kewirausahaan',600000,400000,NULL),(134,'Sarjana','S1 Administrasi Rumah Sakit',600000,450000,NULL),(135,'Sarjana','S1 K3 ( Kesehatan Keselamatan Kerja )',600000,450000,NULL),(136,'Sarjana','S1 Keperawatan',600000,600000,NULL),(137,'Diploma','D3 Keperawatan',600000,750000,NULL);
/*!40000 ALTER TABLE `biaya` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `brosur`
--

DROP TABLE IF EXISTS `brosur`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `brosur` (
  `brosur_id` int NOT NULL AUTO_INCREMENT,
  `kategori` varchar(200) COLLATE utf8mb4_unicode_ci NOT NULL,
  `file` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL,
  PRIMARY KEY (`brosur_id`)
) ENGINE=InnoDB AUTO_INCREMENT=8 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `brosur`
--

LOCK TABLES `brosur` WRITE;
/*!40000 ALTER TABLE `brosur` DISABLE KEYS */;
INSERT INTO `brosur` VALUES (6,'Brosur Belakang','O1xAAqZUXJ3miUtcSvHfH2U84P4Eoda4diYWMYaz.png'),(7,'Brosur Depan','DEiyLkZVVtJ4lKBtcCmiqKXGcu5ZRJ2TZsepMKUR.png');
/*!40000 ALTER TABLE `brosur` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `daftar`
--

DROP TABLE IF EXISTS `daftar`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `daftar` (
  `daftar_id` int NOT NULL,
  `kelas` varchar(30) NOT NULL,
  `nama_leng` varchar(150) DEFAULT NULL,
  `kampus` varchar(100) NOT NULL,
  `al_ktp` varchar(250) DEFAULT NULL,
  `al_dom` varchar(250) DEFAULT NULL,
  `j_kel` varchar(1) DEFAULT NULL,
  `tmpt_lahir` varchar(100) DEFAULT NULL,
  `tgl_lahir` date DEFAULT NULL,
  `no_ktp` varchar(50) DEFAULT NULL,
  `jurusan` varchar(255) DEFAULT NULL,
  `no_hp` varchar(20) DEFAULT NULL,
  `no_wa` varchar(20) DEFAULT NULL,
  `email` varchar(50) DEFAULT NULL,
  `agama` varchar(30) DEFAULT NULL,
  `ibu` varchar(50) DEFAULT NULL,
  `ayah` varchar(50) DEFAULT NULL,
  `jaket` char(5) DEFAULT NULL,
  `lulusan` varchar(60) DEFAULT NULL,
  `sekolah` varchar(100) NOT NULL,
  `biaya` varchar(15) DEFAULT NULL,
  `info` varchar(50) DEFAULT NULL,
  `kerja` varchar(100) DEFAULT NULL,
  `jabatan` varchar(100) DEFAULT NULL,
  `al_kerja` varchar(250) DEFAULT NULL,
  `no_kantor` varchar(20) DEFAULT NULL,
  `created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`daftar_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `daftar`
--

LOCK TABLES `daftar` WRITE;
/*!40000 ALTER TABLE `daftar` DISABLE KEYS */;
INSERT INTO `daftar` VALUES (240008,'Kelas Karyawan','TEGUH WAHYU WIBOWO','Universitas Pandanaran (UNPAND)','desa lau rt 03 rw 02 kecamatan dawe kabupaten kudus','desa lau rt 03 rw 02 kecamatan dawe kabupaten kudus','L','kudus','1999-12-19','3319091912990006','S1 Teknik Sipil','082226377200','085600051990','teguhnusantara1@gmail.com','Islam','masriah','dul ahmad samsi','XL','SMA/MA/SMK/Sederajat','smkk nusantara kudus','Bulanan','Facebook','','','','','2024-06-08 01:21:09'),(240009,'Kelas Karyawan','DACIN','Universitas Pandanaran (UNPAND)','Kyrgyz Republic','Lodge','P','Configuration','2001-02-02','Joly','S1 Manajemen','Laine','Denis','cecilia.wintheiser@projectmy.net','Konghucu','Gina','Embuh','XL','SMA/MA/SMK/Sederajat','Germany','Semesteran','Agency','Monahan LLC','projection','','Durand','2024-06-11 12:34:30'),(240011,'reguler','DIRA FELITA EKA PUTRI','Universitas Pandanaran (UNPAND)','Ngadisari, 04/06, Tempuran, Kaloran, Temanggung','Ngadisari, 04/06, Tempuran, Kaloran, Temanggung','P','Temanggung','2005-12-02','3323054212050002','S1 Akuntansi','083838383703','08816728596','dirafelita22@gmail.com','Budha','Wiwin Wahyuni','Suwarji','XXL','SMA/MA/SMK/Sederajat','SMK Negeri 2 Temanggung','Semesteran','Teman/Keluarga','','','','','2024-06-19 08:30:26'),(240013,'Kelas Karyawan','MUHAMAD LUTHFI FADLURROHMAN','Universitas Pandanaran (UNPAND)','Balapulang Kulon','Jln. Merpati no 48,desa Balapulang Kulon,Kecamatan Balapulang,Kabupaten Tegal','L','Tegal','2004-07-09','3328040907040002','S1 Teknik Sipil','087830350355','089509086701','luthfifadlurrohman7@gmail.com','Islam','Munitah','Nuridin','XXL','SMA/MA/SMK/Sederajat','SMK N 1 Adiwerna','Bulanan','Instagram','','','','','2024-06-20 12:48:55'),(240014,'Kelas Karyawan','DESTI PANDINI','Universitas Pandanaran (UNPAND)','Dusun begelung 1, Tanggamus, Lampung Selatan','Jl. Jomblang legok no. 43a Candisari, Semarang, Jawa Tengah','P','Jabung','2002-07-16','1806155607020005','S1 Manajemen','089663630209','085268962246','dini91417@gmail.com','Islam','Darmayanti','Sukadi','L','SMA/MA/SMK/Sederajat','SMK Negeri 3 Metro','Bulanan','Instagram','','','','','2024-06-21 18:03:11'),(240015,'Kelas Karyawan','GIARTO','Universitas Pandanaran (UNPAND)','Blora Jawa Tengah','Jepang','L','Blora','1999-07-12','3316121207990003','D3 Teknik Mesin','08043787406','085232078664','giarto1207@gmail.com','Islam','Djarmi','Nyadi','L','SMA/MA/SMK/Sederajat','SMK Ma\'arif Tunjungan blora','Semesteran','Google','Yahata kougyo','Welder ','','0565286405','2024-06-22 01:18:37'),(240016,'reguler','IDA AYU FITRIANI','Universitas Pandanaran (UNPAND)','Desa Tegalarum Ngumpul Rt 05 Rw 02 Mranggen Demak','Mranggen Demak','P','Demak','2000-12-27','3321016712000002','S1 Kewirausahaan','083842624871','085212265015','Idaayufitr27@gmail.com','Islam','Mahmudah','Mursidi','S','SMA/MA/SMK/Sederajat','SMA N 1 Mranggen','Bulanan','Instagram','','','','','2024-06-22 13:50:39'),(240017,'Kelas Karyawan','NAFIATUS SHOLIKHAH','Universitas Pandanaran (UNPAND)','Jl.prof.moh.yamin gg delima RT/RW : 03/02 no.62 kel. Duren jaya Kec. Bekasi timur','Aichi ken ,toyoake shi , futamuradai 5-1-1 toyoake danchi 17-305','P','Kediri','1993-08-13','3275015308930014','D3 Teknik Mesin','+62 878-7956-1547','082298483448','zudtta21@gmail.com','Islam','Eni mudrawati','Alm. Saifudin','S','SMA/MA/SMK/Sederajat','SMAN 3 Kediri','Bulanan','Google','Chiyoda kogyo ltd','Karyawan','','0562-47-5313','2024-06-25 08:02:58'),(240018,'Kelas Karyawan','MURJITO','Universitas Pandanaran (UNPAND)','jawa timur  kab bojonegoro kec gayam ds ngeraho RT 08 RW 02','mengikuti tempat kerja','L','bojonegoro','1991-11-02','3522160211910002','S1 Teknik Sipil','085888499981','085888499981','ggatho9973@gmail.com','Islam','mundari','samsuri','L','SMA/MA/SMK/Sederajat','Smkn 1 purwosari bojonegoro','Bulanan','Facebook','Kontrak project','Quality','','085888499981','2024-06-25 13:05:18'),(240019,'Kelas Karyawan','ANGGI SEPTIYANTI','Universitas Pandanaran (UNPAND)','Anggi Septiyanti','Karanganyar rt05/01','P','Banyumas','2000-09-15','3302125509000003','S1 Arsitektur','082329205260','0895379113326','septiyantianggi@gmail.com','Islam','Raswati','Wasisto','L','SMA/MA/SMK/Sederajat','SMKN 2 PURWOKERTO','Bulanan','Instagram','','','','','2024-06-26 02:15:56'),(240020,'Kelas Karyawan','ISMUNIAR MAKMUR','Universitas Pandanaran (UNPAND)','Jl. AndiMappainga Perumahan Pesona barombong imdah blok Aj.no 9 Makassar','Jl.Andimappainga Perumahan Pesona Barombong Indah blom Aj No 9 Makssar','L','Kupang','1977-01-16','7371101601770015','S1 Teknik Sipil','082399535377','081225469244','Ismuniar77elly@gmail.com','Islam','Rimba','Makmur','XL','S1/D4/Sederajat','Universitas Hadanuddin','Semesteran','Facebook','','','','','2024-06-26 05:04:22'),(240021,'Kelas Karyawan','VINA MARGARETA','Universitas Pandanaran (UNPAND)','kranggan, banaran, kalijambe, sragen','kranggan, banaran, kalijambe, sragen','P','sragen','2001-10-22','3314016210010002','S1 Arsitektur','082357419907','082329148815','gretamishubishi@gmail.com','Islam','sri wahyuningsih','margono','S','SMA/MA/SMK/Sederajat','SMA Negeri Gondangrejo','Bulanan','Instagram','','','','','2024-06-28 06:37:13'),(240022,'Kelas Karyawan','SELY FEBRIAN SAGITA','Universitas Pandanaran (UNPAND)','SESEPAN RT 1 RW 1','Sesepan RT 1 RW 1','P','Tegal','2003-02-04','3328044402030003','S1 Akuntansi','+62 859-6429-7184','087816108799','selyfebrian2@gmail.com','Islam','MURYATI','Mahmud','L','SMA/MA/SMK/Sederajat','SMK N 1 SLAWI','Bulanan','Google','','','','','2024-06-30 00:18:50'),(240023,'Kelas Karyawan','DWI FARIDA HANDAYANI','Universitas Pandanaran (UNPAND)','Dk Kembangan, Ds Kembangarum RT09 RW05, Mranggen Demak 59567','Dk Kembangan, Ds Kembangarum RT09 RW05, Mranggen Demak 59567','P','Demak','1984-06-07','3321094706840003','D3 Teknik Kimia','085867772826','085867772826','ida.dwifaridahandayani@gmail.com','Islam','Dwi Cahyo Konfron Ningsih','Suyikno','M','SMA/MA/SMK/Sederajat','Sekolah Menengah Analis Kimia Bogor','Bulanan','Facebook','PT SAPROTAN UTAMA NUSANTARA','Kabag Laboratorium','','','2024-06-30 14:37:48'),(240024,'reguler','AXEL AL BAASITHU','Universitas Pandanaran (UNPAND)','Jln. Budi Utomo no.3 Cilacap','Jln. Belibis no.23 Ciwaduk, Cilegon, Banten','L','Cilacap','2004-04-10','3301211004040003','S1 Teknik Sipil','0882-0066-36910','083857167791','axel.albaasithu100305@gmail.com','Islam','Dwi Susanti Adrianty','Asep Virgo Diana','XL','SMA/MA/SMK/Sederajat','SMK BOEDI OETOMO CILACAP 01','Bulanan','Teman/Keluarga','PT SAFIQ CAKRADAYA MANDIRI','DRAFTER','','0254 601485','2024-07-03 08:55:41'),(240025,'Kelas Karyawan','WIYANTO','Universitas Pandanaran (UNPAND)','tenggar rt/rw: 01/01, Geneng, Bulukerto, wonogiri','tenggar rt/rw: 01/01, Geneng, Bulukerto, wonogiri','L','Wonogiri','1993-06-02','3312180206930001','S1 Teknik Sipil','+62 822-5171-8608','082242336810','wiyanarifin@gmail.com','Islam','Lanjar','Parman','L','SMA/MA/SMK/Sederajat','SMK negeri 1 Bulukerto','Semesteran','Facebook','CV. Akas Mandiri Mediatama','Direktur ','','082242336810','2024-07-07 08:59:03'),(240026,'Kelas Karyawan','RUSWANTO','Universitas Pandanaran (UNPAND)','Ds.Guwoterus Rt/Rw 010/002 Kec.Montong Kab.Tuban','Ds.Guwoterus Rt/Rw 010/002 Kec.Montong Kab.Tuban','L','Tuban','1994-11-10','3523101011940003','D3 Teknik Mesin','083856192684','082244459236','ruswanto300@gmail.com','Islam','Riana','Kusmono','L','SMA/MA/SMK/Sederajat','SMK Taruna Jaya Prawirya Tuban','Bulanan','Teman/Keluarga','PT.BERDIKARI','SPV','','+62356712759','2024-07-11 03:06:45'),(240027,'Kelas Karyawan','KORNELIA KUTUWOT','Universitas Pandanaran (UNPAND)','Miri','Perumahan Ambonggo','P','Miri','2002-08-17','1916055708070001','D3 Teknik Kimia','082398803466','082120549020','andrenelly@gmail.com','Kristen Katholik','Hendrika Dendaguop','Andreas Kondorop','XL','SMA/MA/SMK/Sederajat','SMA 1 N Boven Digoel','Semesteran','Google','','','','','2024-07-15 13:13:40'),(240028,'Kelas Karyawan','AHMAD ADI ARIFIYANTO','Universitas Pandanaran (UNPAND)','Genuksari RT 08 RW 04 Kel genuksari kec Genuk kota Semarang','Genuksari RT 08 RW 04 Kel genuksari kec Genuk kota Semarang','L','Semarang','1995-04-18','33740518049500084','S1 Akuntansi','O','085885943741','adiarfi95@gmail.com','Islam','Masriah','Munasir','L','SMA/MA/SMK/Sederajat','SMK cut nya dien','Bulanan','Instagram','PT kongo Indonesia','Administrasi ','','','2024-07-19 07:09:00'),(240029,'Kelas Karyawan','NANYA MAKHLUFI MAFAZA TSAQIF','Universitas Pandanaran (UNPAND)','Pasuruhan lor','Kudus','L','Kudus','2006-06-19','3319035906060001','S1 Teknik Sipil','085866253877','0895341314300','alfatihrahadal@gmail.com','Islam','Reni Kurniati','Muna\'am','L','SMA/MA/SMK/Sederajat','MA Mu\'allimat Nu Kudus','Bulanan','Teman/Keluarga','','','','','2024-07-19 19:56:50'),(240030,'Kelas Karyawan','DWINI INTAN CANDRANOVI WIBISONO PUTRI','Universitas Pandanaran (UNPAND)','Jalan ksatrian G27 Jatingaleh Candisari Semarang','Semasang','P','Semarang','1994-11-28','3404026811940002','D3 Administrasi Bisnis','087739325000','087739325000','intanbisono@gmail.com','Islam','Evi kurniawati','Gunawan Wibisono','XL','SMA/MA/SMK/Sederajat','SMA N 4 Yogyakarta','Bulanan','Instagram','Horison Inn Antawirya','Human resource supervisor','','024678678','2024-07-20 01:50:59'),(240032,'Kelas Karyawan','LENAS URBAN','Universitas Pandanaran (UNPAND)','Kupialat','Dekai','L','Kupialat','2024-04-04','9113420603960001','S1 Kewirausahaan','082197692603','081276333440','lensonurbanurbanlenson@gmail.com','Kristen Protestan','Baulina maling','Marten urban','L','SMA/MA/SMK/Sederajat','Makasar','Bulanan','Facebook','','','','','2024-07-26 21:51:20'),(240033,'reguler','DIVA MAMTA NURAMALIA','Universitas Pandanaran (UNPAND)','Pagedangan 03/01 Kec. Adiwerna','Tegal','P','Tegal','2005-02-27','3328116502050002','S1 Akuntansi','+62 895-4230-02032','087716856711','diva811@gmail.com','Islam','Suciati','Warjo','M','SMA/MA/SMK/Sederajat','SMK NU 1 Slawi','Bulanan','Teman/Keluarga','','','','','2024-07-27 03:05:04'),(240034,'Kelas Karyawan','KURNIA SANDO PRADANA','Universitas Pandanaran (UNPAND)','Jl.BUKIT CEMARA INDAH VI CF NO.36','Jl. BUKIT CEMARA INDAH VI NO.36 RT.05 RW.13 METESEH, TEMBALANG','L','KOTA SEMARANG','2003-10-23','3374102310030001','S1 Teknik Sipil','082136125930','088232819672','kurnia.sando20@gmail.com','Islam','Santimurtiana','Widodo','L','SMA/MA/SMK/Sederajat','SMA MARDISISWA','Bulanan','Instagram','','','','','2024-07-28 22:54:14'),(240035,'reguler','JAINUDIN MABUD','Universitas Pandanaran (UNPAND)','Kel.Ngade','Perumhan Low Permai Blok A No 14','L','Tabajaya','1979-12-29','8271021229790003','S1 Teknik Sipil','082187038253','082271419088','dinomilan97@gmail.com','Islam','Sai Taib','Mabud Hi Kabir','XXL','SMA/MA/SMK/Sederajat','SMA Muhammadiyah Maluku Utara','Semesteran','Facebook','','','','','2024-07-31 02:50:58'),(240036,'Kelas Karyawan','AKAR NAGA SURYANATA','Universitas Pandanaran (UNPAND)','Jalan kawi 3 rt 04 rw 04','Jalan kawi 3 rt 04 rw 04','L','Jakarta','2000-04-19','3374081904000001','S1 Teknik Sipil','089611025588','081366165246','akarnagasuryanata02@gmail.com','Islam','Tarmini nurtiyanti','Kusriyanto','XL','SMA/MA/SMK/Sederajat','Smk negeri 7 semarang','Bulanan','Teman/Keluarga','Hutama karya infrastruktur','Staff teknik','','0218191584','2024-08-02 03:27:51'),(240037,'reguler','SOLIHIN','Universitas Pandanaran (UNPAND)','Bugel kesenengan Mojotengah','Wonosobo','L','Bugel keseneng','2006-12-07','3307070712060005','S1 Manajemen','-','083194783758','solihinj584@gmail.com','Islam','Waginem','Pardal','XL','SMA/MA/SMK/Sederajat','SMK NU KEJAJAR WONOSOBO','Semesteran','Instagram','','','','','2024-08-03 08:23:03'),(240038,'reguler','KHAIRUL MAULANA ALIFIYANSYAH','Universitas Pandanaran (UNPAND)','Desa Kendayakan rt.006/rw.001 Kecamatan Warureja Kabupaten Tegal','Jl. Bumi Taruno Permai No. 08 Adiarsa Barat â€“ Karawang Barat. Kab. Karawang â€“ Jawa Barat','L','Tegal','1995-04-30','3328173004950001','S1 Arsitektur','083842681817','081227445447','khairulmaulana15@gmail.com','Islam','Umi Dewanti','Tarim','L','D3/Sederajat','Universitas Diponegoro','Bulanan','Brosur','','','','','2024-08-04 09:45:01'),(240039,'reguler','AMIRIN SUNTORO','Universitas Pandanaran (UNPAND)','Mejobo Kidul,RT 05 RW 04,Desa Mejobo,Kec.Mejobo,Kab.Kudus,Jawa Tengah','Desa Mejobo,RT 05 RW 04 Mejobo Kudus Jawa Tengah','L','Kudus','1998-05-14','3319051405980005','D3 Administrasi Bisnis','089515529063','0882008334480','tachiboku00@gmail.com','Islam','Jumari','Sanusi','L','Paket C','PKBM Intan Prima Mandiri','Bulanan','Instagram','','','','','2024-08-04 15:19:36'),(240040,'Kelas Karyawan','ADY ISHARYANTO','Universitas Pandanaran (UNPAND)','MOJOSARI RT 03 RW 01 BEKONANG MOJOLABAN SUKOHARJO','MOJOSARI RT 03 RW 01 BEKONANG MOJOLABAN SUKOHARJO','L','SUKOHARJO','1985-05-10','3311081005850001','S1 Teknik Sipil','089512020207','085878967180','ady.milano10@gmail.com','Islam','SUNARTI','SUTARNO','M','SMA/MA/SMK/Sederajat','SMA NEGERI 1 MOJOLABAN','Bulanan','Google','','','','','2024-08-04 15:20:28'),(240041,'reguler','BOBI KAROMAH','Universitas Pandanaran (UNPAND)','Blok kemasan 1 rt.02 rw.01 desa keduanan kec.Depok kab.Cirebon','Japan nagano Ken kamiina gun minowa machi naka minowa 11750 banchi leopalace skyhigh 108','L','Cirebon','1996-05-14','3209181405960009','D3 Teknik Mesin','+62 853-2023-7479','085724445135','shinobimichishoukai01@gmail.com','Islam','Juriyah','Sari','L','SMA/MA/SMK/Sederajat','Smk teknik bakti persada','Bulanan','Agency','Shinko Co.ltd japan','Operator','','05068809935','2024-08-06 08:41:26'),(240042,'Kelas Karyawan','LATHIFA AULIA SURYA','Universitas Pandanaran (UNPAND)','Jatisari permai blok A12/20 Rt 08 Rw 09, Jatisari, Mijen, Semarang.','Kallista Residence Blok B3 A, mijen, semarang.','P','Semarang','2001-07-28','3374136807010003','S1 Manajemen','089635680656','089524582069','lathifaaulias18@gmail.com','Islam','Lilik Sulistyorini','Wiono','L','SMA/MA/SMK/Sederajat','SMK N 7 Semarang','Bulanan','Teman/Keluarga','PT SIGAWE KARYA BERSAUDARA','Sosial Media Specialist','','087748005201','2024-08-07 07:44:27'),(240043,'reguler','ARIF OCTAVIAN DANU','Universitas Pandanaran (UNPAND)','Krajan RT 01/RW 02, Lemahireng, Bawen, Kabupaten Semarang','Krajan RT 01/RW 02, Lemahireng, Bawen, Kabupaten Semarang','L','KAB. SEMARANG','1995-10-15','3322111510950002','D3 Teknik Mesin','085228898338','085799447144','arifod15@gmail.com','Islam','RUMINAH','SUPADI','XL','SMA/MA/SMK/Sederajat','SMA N 2 UNGARAN','Bulanan','Teman/Keluarga','PT. SURYA KUSUMA NUSANTARA','INSPEKTOR','','0298-521189','2024-08-08 08:32:39'),(240044,'reguler','REGI YULI SETIO','Universitas Pandanaran (UNPAND)','MAJAKERTA RT 03/ RW 04 Kec.Watukumpul Kab.Pemalang','Semarang Kedungmundu','L','PEMALANG','2006-07-24','3327042407060002','S1 Teknik Sipil','088291942428','083839441620','regiyulisetio625@gmail.com','Islam','ROISAH','TOMO','L','SMA/MA/SMK/Sederajat','SMK N 1 RANDUDONGKAL','Bulanan','Teman/Keluarga','','','','','2024-08-12 07:46:35'),(240046,'Kelas Karyawan','HAPSARI NAWANG SEKAR','Universitas Pandanaran (UNPAND)','Delok(rt01/rw07), Gesing, Kandangan','Delok(rt01/rw07), Gesing, Kandangan','P','Temanggung','2004-05-25','3323066505040001','S1 Teknik Sipil','081905502941','087733554222','hapsarinawang67@gmail.com','Islam','Imatul Ngadimah','Mahmudi','M','SMA/MA/SMK/Sederajat','SMK Dr. Sutomo Temanggung','Bulanan','Instagram','CV. Terang Abadi Satria','Staff Teknis','','087733356438','2024-08-13 08:21:50'),(240047,'Kelas Karyawan','RAFI ANDIKA DADMAWAN','Universitas Pandanaran (UNPAND)','JALAN TIDORE','JALAN TIDORE','L','MERAUKE','2005-11-03','9101010311050001','S1 Teknik Sipil','082398106003','082399666759','bnasquadracorse@gmail.com','Islam','MUNASAROH','SUTIKNYO','XL','SMA/MA/SMK/Sederajat','SMAIT IBNU KHALDUN','Semesteran','Google','','','','','2024-08-15 06:02:45'),(240048,'reguler','RAFINDRA HAKIM WICAKSONO','Universitas Pandanaran (UNPAND)','Lebuawu pecangaan Jepara','Jln ringin bhakti raya no.62 Kramas tembalang Jepara','L','Jepara','2003-01-24','3320112401020001','S1 Manajemen','+62 895-3715-59654','089672342040','rafindrahakim9@gmail.com','Islam','Surati','Fathoni M. Nur','L','SMA/MA/SMK/Sederajat','Smk walisongo Pecangaan','Bulanan','Instagram','Pt Albany corona','Crew storw','','(021) 6909400','2024-08-23 03:54:07'),(240049,'reguler','JHON HENRY TIARANA','Universitas Pandanaran (UNPAND)','jl.cilik riwut','Kalimantan tengah','L','sukamara','2006-07-02','62080102020706001','S1 Manajemen','082154362652','085608511568','jhonhenrytiarana@gmail.com','Kristen Katholik','muntiara','nadi','M','SMA/MA/SMK/Sederajat','SMA PGRI 6 MALANG','Semesteran','Teman/Keluarga','','','','','2024-08-23 07:09:38'),(240050,'Kelas Karyawan','YUSUP RIYANTO','Universitas Pandanaran (UNPAND)','Dusun Pananjung Timur, RT031/007, Kel Sinartanjung, Kec Pataruman','Dusun Pananjung Timur, RT031/007, Kel Sinartanjung, Kec Pataruman','L','Ciamis','1996-11-04','3279020411960003','S1 Teknik Sipil','081282698593','081277854045','Yusupriyanto23@gmail.com','Islam','Siti Aminah','Rastaman','L','SMA/MA/SMK/Sederajat','SMK Bina Putera Banjar','Semesteran','Teman/Keluarga','PT.Hutama Karya Infrastruktur','Staff Teknik','','0218191584','2024-08-23 12:57:47'),(240051,'Kelas Karyawan','ANIF MUASYAROH','Universitas Pandanaran (UNPAND)','Puguh','Puguh','P','Kendal','1993-09-27','3324076709930001','S1 Kewirausahaan','08515993963','082221887685','oerioen@gmail.com','Islam','Solikhatin','Sarroji','XL','SMA/MA/SMK/Sederajat','SMA negeri 1 boj','Semesteran','Facebook','','','','','2024-08-24 11:59:21'),(240052,'Kelas Karyawan','PRATIDINA SIGIT PAMUNGKAS','Universitas Pandanaran (UNPAND)','Jalan Sawunggaling timur no 6','Jalan Sawunggaling timur no 6','L','Semarang','2006-06-28','3374112806060002','S1 Manajemen','0856743114757','089531196688','pratidinasigit6@gmail.com','Islam','Subaryati','Teguh Setianto','L','SMA/MA/SMK/Sederajat','SMAN 9 Semarang','Semesteran','Teman/Keluarga','','','','','2024-08-25 12:27:42'),(240053,'reguler','MOCHAMMAD YUSUF','Universitas Pandanaran (UNPAND)','Perum eagle residence kav 3 smg','Perum eagle residence kav 3 smg','L','Semarang','1980-09-12','3374031209800003','S1 Teknik Sipil','085325924664','085325924664','yusuf.805ciptainti@gmail.com','Islam','Martutik','Solichin','XL','SMA/MA/SMK/Sederajat','Transfer dari undip','Bulanan','Facebook','PT. CIPTA INTI MANUNGGAL','Direktur','','085325924664','2024-08-30 06:23:42'),(240054,'reguler','AGUNG WIBOWO','Universitas Pandanaran (UNPAND)','Jalan Lebdosari Raya RT 09 RW 05','Jalan Lebdosari Raya RT 09 RW 05','L','Semarang','1989-08-02','3374130208890002','S1 Teknik Sipil','085641791989','085641791989','agungwibowoaw020889@gmail.com','Kristen Protestan','Anna Dwi Ratna Sari','Sugiyanto alm.','XL','SMA/MA/SMK/Sederajat','SMK NEGERI 7 (STM PEMBANGUNAN) Semarang','Bulanan','Teman/Keluarga','CV. AGSA WISDOM PRO','Direktur','','085641791989','2024-08-31 08:00:54'),(240055,'Kelas Karyawan','ZITA HANNA MARISKA','Universitas Pandanaran (UNPAND)','dk panjatan rt 01 rw 01 kecamatan warureja Kabupaten Tegal','dk panjatan rt 01 rw 01 kecamatan warureja Kabupaten Tegal','P','Pemalang','2003-12-04','3327014412030041','S1 Teknik Sipil','085691375755','085861600890','zitahanna08@gmail.com','Islam','Suimah','Warto','S','SMA/MA/SMK/Sederajat','SMK SUPM YAMIPURA','Semesteran','Teman/Keluarga','PT MANUNGGAL KABEL INDONESIA','Operator ','','','2024-09-03 09:24:39'),(240056,'Kelas Karyawan','DIDIK AGUS PURNOMO','Universitas Pandanaran (UNPAND)','Ngeluh kandong rejo','Ngeluh kandang rejo','L','Grobogan','1997-11-09','3315150911970004','S1 Teknik Sipil','Tidak ada','081225692588','didikagus753@gmail.com','Islam','Suwartini','Sumarno','XL','SMA/MA/SMK/Sederajat','SMA n 1 godong','Semesteran','Instagram','Wijaya karya','Pelaksana','','Tidak ada','2024-09-03 10:14:37'),(240057,'reguler','AGUS SETIAWAN','Universitas Pandanaran (UNPAND)','Kemiri RT 2 RW 1,Kec. SUMPIUH Kab. Banyumas','Wonolopo RT 9 RW 1,KECAMATAN MIJEN','L','Banyumas','2002-08-15','3302071508020003','D3 Teknik Kimia','085640074601','085700781368','agussetiawan13b@gmail.com','Islam','Darinah','Salimun','M','D3/Sederajat','SMK MAARIF NU 1 SUMPIUH','Bulanan','Google','PT GS BATTERY SEMARANG','Supply material line produksi','','','2024-09-06 00:01:18'),(240058,'reguler','DIDIK AGUS PURNOMO','Universitas Pandanaran (UNPAND)','Ngeluh kandong rejo','Ngeluh kandang rejo','L','Grobogan','2024-09-09','3315150911970004','S1 Teknik Sipil','Tidak ada','081225692588','didikagus753@gmail.com','Islam','Suwartini','Sumarno','XL','SMA/MA/SMK/Sederajat','SMA n 1 godong','Bulanan','Instagram','Wijaya karya','Pelaksana','','Tidak ada','2024-09-08 02:56:26'),(240059,'reguler','DIMAS PRAYOGA','Universitas Pandanaran (UNPAND)','NGADISARI RT 004 RW 006 TEMPURAN, KEC KALORAN','Ngadisari Rt 004 Rw 006 Tempuran, Kec Kaloran, Kab Temanggung Jawa Tengah','L','Temanggung','2005-12-05','3323050512050004','S1 Manajemen','0838-3896-2658','085726869029','dp829250@gmail.com','Budha','Ginah','Parsito','L','SMA/MA/SMK/Sederajat','SMK Dr SUTOMO TEMANGGUNG','Semesteran','Teman/Keluarga','Hotel arho','Housekeeping','','08122822280','2024-09-09 00:46:45'),(240060,'Kelas Karyawan','HIDAYAT SAMSI','Universitas Pandanaran (UNPAND)','Desa Tauro RT. 001 RW. 001 Kec. Jailolo-Halmahera Barat','Kota Ternate','L','Tauro','1993-11-02','8201010211930002','S1 Teknik Sipil','085757383327','081398886652','dhaisha7@gmail.com','Islam','Fatma Ayunang','Usman Syamsi','M','SMA/MA/SMK/Sederajat','SMK N 1 Jailolo','Semesteran','Facebook','PT. Bina Karya Malut','Direktur','','081398886652','2024-09-10 04:41:36'),(240061,'reguler','SHOLIKHAT','Universitas Pandanaran (UNPAND)','GEBUDAN RT 03 RW 05 Desa Gentinggunung Kec Sukorejo Kab Kendal','GEBUDAN RT 03 RW 05 Desa Gentinggunung Kec Sukorejo Kab Kendal','L','kendal','1996-12-11','3324031112960002','S1 Kewirausahaan','085727148070','082268384086','alexandresolly@gmail.com','Islam','TURMI','BUSARI','M','SMA/MA/SMK/Sederajat','SMK MUHAMMADIYAH 04 SUKOREJO KAB KENDAL','Semesteran','Google','SUKA HIJAU FARM','PEMILIK/ OWNER','','082268384086','2024-09-16 05:18:32'),(240062,'Kelas Karyawan','DEWI SAPUTRI','Universitas Pandanaran (UNPAND)','Gedang Anak Rt 3 Rw 6','Gedang Anak Rt 3 Rw 6','P','Semarang','1988-06-03','3322194306880002','S1 Manajemen','081240041302','08123666246','dewisaputribankjateng@gmail.com','Islam','winanti','joko pramono','L','D3/Sederajat','universitas diponegoro','Bulanan','Datang Langsung','bank jateng','settlement bank indonesia','','0243557451','2024-09-17 04:03:51'),(240063,'reguler','ELRA NATHANIA','Universitas Pandanaran (UNPAND)','langgongsari rt 1 rw 3, cilongok, banyumas, jawa tengah','langgongsari rt 1 rw 3, cilongok , banyumas, jawa tengah','P','karawang','1998-11-27','3302176711980002','S1 Kewirausahaan','085133731040','085133731040','elna.nathania98@gmail.com','Kristen Katholik','Christin Yulianti','Ronny Setiawan','L','SMA/MA/SMK/Sederajat','sma bruderan purwokerto','Bulanan','Agency','','','','','2024-09-19 07:21:55'),(240064,'reguler','MARIA ULFA','Universitas Pandanaran (UNPAND)','Perum kenari indah2.Rt005,Rw008.sarirejo kaliwungu','Perum kenari indah 2.Rt005,Rw008.sarirejo kaliwungu','P','Kendal','1986-04-01','3175054104860009','S1 Kewirausahaan','081219422366','082210638466','Ekosukatno809@gmail.com','Islam','Erma nurhidayah','M Taufani','XL','SMA/MA/SMK/Sederajat','SmA Nurul islami','Bulanan','Instagram','','','','','2024-09-20 12:45:06'),(240065,'Kelas Karyawan','RIYAN PRASETYO','Universitas Pandanaran (UNPAND)','Jalan Ngemplak RT 04 RW 09','Jalan Ngemplak RT 04 RW 09','L','Semarang','2002-07-23','3374102307020003','S1 Manajemen','87893308496','8882007263711','riyanprasetya2002@gmail.com','Kristen Protestan','Sunarti','Iki subki','XL','SMA/MA/SMK/Sederajat','Smk Pangudi luhur tarcisius','Bulanan','Instagram','PT ninja express','Swasta ','','-','2024-09-27 08:16:16'),(240067,'Kelas Karyawan','PUTRA LANANGAZI','Universitas Pandanaran (UNPAND)','Jl MT HARYONO GG 24','JL MT HARYONO GG24','L','Pasuruan','1987-07-02','3514100207870003','S1 Teknik Sipil','081387231969','085921740100','pazi9246@gmail.com','Islam','Azizah','I Soepada','XL','SMA/MA/SMK/Sederajat','SMA 1 BUMIAYU','Semesteran','Instagram','CV ADJIAN NUSANTARA','Direktur','','085921740100','2024-09-28 05:36:36'),(240068,'reguler','NORBERTHUS HAPPY DWI PRAJOKO','Universitas Pandanaran (UNPAND)','Kranggan  Rt003/005 Kranggan, Temanggung','Kranggan  Rt003/005 Kranggan, Temanggung','L','Kabupaten Temanggung','1972-01-31','3274033101720002','S1 Manajemen','081277205371','081277205371','happydwiprjoko@gmail.com','Kristen Katholik','Maria Praptiningsih','Ign. Soemarsono','L','D3/Sederajat','AKA Wika Jasa semarang','Bulanan','Teman/Keluarga','Kanwil DJKN Jateng dan DI Yogyakarta','Pelaksana','','024-3545987','2024-09-30 07:45:18'),(240069,'Kelas Karyawan','TUBUN INDRA ISMAIL','Universitas Pandanaran (UNPAND)','Jl.Jendral Sudirman no.13,RT 058,Sangatta Utara,Sangatta Utara,Kutai Timur,Kalimantan Timur','Jl.Jendral Sudirman no.13,RT 058,Sangatta Utara,Sangatta Utara,Kutai Timur,Kalimantan Timur','L','Wonosobo','2003-01-09','3307020901030002','D3 Teknik Mesin','08221427450','08812704643','tubunindraismail054@gmail.com','Islam','Indaryati','Miftah Sururi','L','SMA/MA/SMK/Sederajat','Smk Pembaharuan Purworejo','Bulanan','Instagram','PT.Tjokro Bersaudara Sangattaindo','Operator Planer','','6254925397','2024-10-02 09:07:51'),(240070,'Kelas Karyawan','KUSYAJIB YAMUTADIR','Universitas Pandanaran (UNPAND)','Dsn.kemambang rt 02 / 01 kec.banyubiru kab.semarang','Dsn.kemambang','L','Kab.semarang','1987-05-17','3322071705870005','S1 Teknik Sipil','08390091288','083134319283','kusyajib87@gmail.com','Islam','Asmiah','Al khaerum','L','SMA/MA/SMK/Sederajat','Smk dr tjipto ambarawa','Semesteran','Facebook','Dpu','Tim teknis','','','2024-10-08 00:24:28'),(240071,'Kelas Karyawan','RULLY SURYAMAHARDIKA','Universitas Pandanaran (UNPAND)','jl drupada 13 rt 05 rw015 no 29','Perm griya emerald blok B no 11 kel sumbang kec banteran kab banyumas','L','jakarta','1979-06-30','3271053006790019','S1 Manajemen','087881518454','081717279148','rl.mahardika@gmail.com','Islam','suryatie','sangkuto chaerulsyah','XL','SMA/MA/SMK/Sederajat','SMU AL CHASANAH','Bulanan','Facebook','ASSTON HOTEL PURWOKERTO','F&B MANAGER','','(0281) 628000','2024-10-08 08:02:37'),(240074,'Kelas Karyawan','ISNANI NUR FADILAH','Universitas Pandanaran (UNPAND)','dusun masuhan','masuhan bandung harjo rt03/rw04','P','grobogan','2005-09-11','3315045109050006','S1 Manajemen','089506173553','089506173553','isnaninurfadilah@gmail.com','Islam','haryati','suratin','L','SMA/MA/SMK/Sederajat','sma n 1 toroh','Bulanan','Instagram','','','','','2024-10-09 05:39:07'),(240075,'reguler','PAMUJI ROHMAD','Universitas Pandanaran (UNPAND)','Desa Dowan rt 01 rw 02 kec. Gunem kab. Rembang','Rembang','L','Rembang','1998-08-12','3317031208980001','S1 Manajemen','085729108918','08112579991','bozpam067@gmail.com','Islam','Padmiati','Parji','L','SMA/MA/SMK/Sederajat','SMK negeri 1 gunem','Bulanan','Facebook','Cv Setya tirta jaya','Admin','','085640647779','2024-10-10 12:24:33'),(240076,'Kelas Karyawan','SURYA FAHRUL PRASONO','Universitas Pandanaran (UNPAND)','Jl Desa Cikawung Rt 03/02','Jl Desa Cikawung Rt 03/02','L','KAB. BANYUMAS','2002-09-14','3175081409020005','S1 Manajemen','082114789681','082138834762','fahrulsurya74@gmail.com','Islam','Endang catur','Sumarsono','XL','SMA/MA/SMK/Sederajat','SMK Muhammadiyah 1 Ajibarang','Bulanan','Facebook','PT HM Sampoerna','Satpam','','-','2024-10-11 02:21:08'),(240077,'Kelas Karyawan','SULIH UTAMI','Universitas Pandanaran (UNPAND)','Randugunting Rt 04 RW 01 Kec Bergas Kab Semarang','Randugunting RT 05 Rw 03 kec bergas kab semarang','P','kabupaten semarang','1988-08-09','3322134908880001','S1 Arsitektur','082134136182','082134136182','utamisulih@gmail.com','Islam','suparni','rahmadi','M','SMA/MA/SMK/Sederajat','SMK kanisius ungaran','Bulanan','Facebook','Pt starlight garment semarang','admin','','0298 525556','2024-10-18 07:46:54'),(240078,'Kelas Karyawan','MUHAMMAD RIO ADITTIA','Universitas Pandanaran (UNPAND)','Batuagung','TEGAL','L','TEGAL','2006-02-05','3328040502060001','S1 Teknik Sipil','085320177171','082339488549','mrioadiitiaa@gmail.com','Islam','ROKHAYATI','WASTORI','L','SMA/MA/SMK/Sederajat','SMA negeri 1 balapulang','Semesteran','Instagram','Bank mandiri','Security ','','','2024-10-20 08:03:22'),(240079,'Kelas Karyawan','HARIS WIJAYANTO','Universitas Pandanaran (UNPAND)','Jl. Lempuyang IV Banyumanik','Jl. Lempuyang IV Banyumanik','L','Semarang','2001-11-16','3374071611010002','S1 Akuntansi','085226755078','08895267050','hariswijayanto197@gmail.com','Islam','Hersy Handari','Suyanto','XL','SMA/MA/SMK/Sederajat','SMA Sint Louis Semarang','Semesteran','Facebook','','','','','2024-10-21 01:55:19'),(240080,'reguler','IRFAN RAIS SAPUTRA','Universitas Pandanaran (UNPAND)','jl bugen utara rt05 rw03 bangetayu kulon genuk semarang','jl bugen utara rt05 rw03 bangetayu kulon genuk semarang','L','KOTA SEMARANG','2000-12-15','3374051512000004','D3 Teknik Mesin','082242692398','085326236448','irpanrais90@gmail.com','Islam','Sutami Indriyani','Sujiyanto','L','SMA/MA/SMK/Sederajat','MAN 1 KOTA SEMARANG','Bulanan','Instagram','','','','','2024-10-26 02:48:25'),(240081,'reguler','JANICE FINNA ANNORA','Universitas Pandanaran (UNPAND)','SENDANGGUWO RT 16 RW 09','SENDANGGUWO RT 16 RW 09','P','SEMARANG','2002-01-01','3374084101010003','S1 Manajemen','081393905180','083838683082','janiceannora@gmail.com','Kristen Protestan','ESSY FILA NIANDARI','ISNA FUMIRA HARJANTO','XL','SMA/MA/SMK/Sederajat','SMA SINT LOUIS SEMARANG','Semesteran','Teman/Keluarga','','','','','2024-11-12 01:24:53'),(240082,'reguler','SAVERO TRISTAN ADINATA','Universitas Pandanaran (UNPAND)','Sendangguwo','Semarang','L','Semarang','2006-09-19','3374081909060002','S1 Kewirausahaan','+62 813-9390-5180','0831-3383-3928','saveroadinata580@gmail.com','Kristen Protestan','Essy filla niandari','Isna fumirahardjanto','L','SMA/MA/SMK/Sederajat','SMA Masehi 2 PSAK','Bulanan','Teman/Keluarga','','','','','2024-11-12 02:10:06'),(240084,'reguler','SITI SURAYA','Universitas Pandanaran (UNPAND)','Tebaban timur, Desa Tebaban, Kec. Suralaga, Kab. Lombok Timur, NTB','Tebaban timur, Desa Tebaban, Kec. Suralaga, Kab. Lombok Timur, NTB','P','Tebaban timur, Desa Tebaban, Kec. Suralaga, Kab. Lombok Timur, NTB','2001-06-03','5203136704020004','S1 Akuntansi','087754245604','081919212221','surayasiti072@gmail.com','Islam','Husniatun','Busairi','S','SMA/MA/SMK/Sederajat','MA Sakinatul Walidain NW Borok Gerung','Semesteran','Instagram','','','','','2024-11-19 04:46:55'),(240085,'reguler','FAKHRIZAL ARIFUDIN','Universitas Pandanaran (UNPAND)','Jl. Curug Cipendok rt 1 RW 2','Cilongok','L','Banyumas','1986-12-22','3302172212860005','S1 Manajemen','0895341741022','0895341741022','rj.azonic@gmail.com','Islam','Napsiyah','Warkim','M','D3/Sederajat','Universitas jenderal soedirman','Bulanan','Agency','','','','','2024-11-21 04:38:40'),(240088,'Kelas Karyawan','MERLIN GRACE WAKUM','Universitas Pandanaran (UNPAND)','Kampung rim biak timur papua','Papua barat manokwari','P','Biak','2002-07-29','9106036907020001','D3 Administrasi Bisnis','082198968953','081285382398','merlynwakum29@gmail.com','Kristen Protestan','Anthoneta t rumaropen','Alian p wakun','L','SMA/MA/SMK/Sederajat','Sma ypk 1 biak','Bulanan','Facebook','','','','','2024-11-28 10:11:34'),(240089,'reguler','RAHADYAN SAHID WISNUWARDHANA','Universitas Pandanaran (UNPAND)','Jalan Mulia A4/1 Griya Mulya Loka Klipang Semarang','Jalan Mulia A4/1 Griya Mulya Loka Klipang Semarang','L','Kota Semarang','1990-12-23','3374072312900001','S1 Teknik Sipil','081215371439','088225098056','rahadyansahid23@gmail.com','Islam','Niniek Pudji Astuti','M. Iskono Soemarno, B.A','XL','D3/Sederajat','Politeknik Negeri Semarang','Bulanan','Facebook','','','','','2024-12-01 02:12:56'),(240090,'reguler','NUR HASANAH','Universitas Pandanaran (UNPAND)','Gondangan Rt24 Rw03 Gumelar,Wadaslintang,Wonosobo, Jawa Tengah','Jln bukit putra l, bukit Sari, Ngesrep Banyumanik, Semarang','P','Wonosobo','1993-05-13','3307015305930003','S1 Kewirausahaan','085247229589','081229841299','nissak989@gmail.com','Islam','Ginem','Ahmad Yusri','L','Paket C','PKBM Ar Rohmah','Bulanan','Datang Langsung','','','','','2024-12-04 13:25:28'),(240092,'Kelas Karyawan','BREHMAN J HUTAGALUNG','Universitas Pandanaran (UNPAND)','Dusun II Desa Tanah Rendah Kecamatan Air Putih kabupaten Batubara Provinsi Sumatera Utara','Batubara','L','Tanah Tinggi','1996-07-27','1219032010980003','D3 Teknik Mesin','082168204416','081269202293','galungb67@gmail.com','Kristen Protestan','Nurhaini Manalu','Jhoni Hutagalung','L','SMA/MA/SMK/Sederajat','SMK Negeri 1 Air Putih','Bulanan','Instagram','PT.imari Nourriture Indonesia','Store Man ','','','2024-12-15 20:27:28'),(240093,'reguler','DIAS ALFIJAR','Universitas Pandanaran (UNPAND)','Sinar harapan Mulya kec.Teluk gelam kab.oki Sumsel','Bringin kulon ,kel.tambak aji kec.ngaliyan kota Semarang','L','MERABUNG 1','2001-05-10','1602231005010004','S1 Manajemen','082373129363','085219223381','diasalfijar9@gmail.com','Islam','Upik','Ngatiman','XL','SMA/MA/SMK/Sederajat','SMKN 1 LEMPUING JAYA','Semesteran','Instagram','PT Indosari Niaga Nusantara','Operator ','','085219213381','2024-12-17 01:15:15'),(240094,'reguler','RIKIYANTO','Universitas Pandanaran (UNPAND)','GG M SALEH RT 004 DESA BENUA BARU ILIR','GG M SALEH','L','DEMAK','2001-04-26','6408052604000001','S1 Manajemen','085173387891','085947526657','yriki1264@gmail.com','Islam','NURIDA','NGADENAN','XXL','Paket C','PKBM CAHAYA MENTARI','Bulanan','Facebook','','','','','2024-12-19 09:45:49'),(240095,'Kelas Karyawan','AMIN ISKANDAR','Universitas Pandanaran (UNPAND)','JL. LEMBAH DAMAI KELURAHAN LEMBAH DAMAI KECAMATAN RUMBAI PESISIR','JL. SIRSAK 1 BLOK C.17/13 PANDAU PERMAI','L','KASIMANG','1982-05-26','2105012605820001','S1 Manajemen','081268939911','081268939911','tengku.andyrokan82@gmail.com','Islam','DETTY FARIDA','TENGKU AMIRUDDIN','L','D3/Sederajat','DIPLOMA III PERPAJAKAN FAKULTAS EKONOMI UNIVERSITAS RIAU','Bulanan','Instagram','BADAN KEUANGAN DAERAH KABUPATEN SIAK','KASUBBAG TATA USAHA','','','2024-12-23 07:20:08'),(240096,'Kelas Karyawan','RUDI KURNIYANTO','Universitas Pandanaran (UNPAND)','Jl kinasih Gemawang RT 03 RW 01 MUNDIING KCAMTA BERGAS KABUPATEN SEMARANG','Jl kinasih Gemawang Munding','L','Kabupaten Semarag','2000-07-13','3322131307000001','D3 Teknik Mesin','082134137446','0895375606816','rudi.rr46@gmail.com','Islam','Atiyah','Suryanto','XL','SMA/MA/SMK/Sederajat','SMK NU UNGARAN','Bulanan','Teman/Keluarga','','','','','2024-12-24 09:32:14'),(240097,'Kelas Karyawan','MIFTAKHUR RIZKY','Universitas Pandanaran (UNPAND)','Desa Pucangrejo, rt 4 rw 4, Kec Gemuh, Kab. Kendal','Desa Pucangrejo, rt 2 rw 2, Kec Gemuh, Kab. Kendal','L','Kendal','2003-01-03','3324110301030001','S1 Teknik Sipil','087821908022','089605360607','miftakhurrizky23@gmail.com','Islam','Siti Nur Asiyah','Suharmawan','L','D3/Sederajat','Politeknik Industri Furnitur dan Pengolahan Kayu','Bulanan','Google','PT Ebako Nusantara','Staff Quality Control','','','2024-12-24 13:07:35'),(250001,'Kelas Karyawan','MANSUR SAIFUDIN','Universitas Pandanaran (UNPAND)','Dk. Sirahan RT 007 RW 001 Desa Plajan, Kec. Pakis Aji, Kab. Jepara','Dk. Sirahan RT 007 RW 001 Desa Plajan, Kec. Pakis Aji, Kab. Jepara','L','Jepara','1992-04-23','3320152304920003','D3 Teknik Mesin','082133452777','082133452777','mansyur.43@gmail.com','Islam','Ngatiyem','Mat Kosim','XXL','SMA/MA/SMK/Sederajat','SMA Muhammadiyah Bangsri','Semesteran','Google','','','','','2025-01-04 02:53:54'),(250003,'reguler','IKE YOLANDA SARI','Universitas Pandanaran (UNPAND)','Jl. Kartini Desa B.Srikaton, Tugumulyo, Musi Rawas, Sumatera Selatan','Jl. Puri Banjaran III Blok B14, Bringin, Ngaliyan, Kota Semarang','P','Arga makmur','1993-09-26','1605016609930005','D3 Administrasi Bisnis','081377761701','081377761701','ikkeyolandasari@gmail.com','Islam','Mimin Aminah','Imran Bastari','M','SMA/MA/SMK/Sederajat','SMAN 1 Tugumulyo','Bulanan','Instagram','PT Primafood International (Charoen Pokphand Group)','HR Trainer','','(024) 7611662','2025-01-07 06:30:23'),(250005,'Kelas Karyawan','DWI SIWI IRMA DAMAYANTI','Universitas Pandanaran (UNPAND)','dusun jetak rt 05 rw 04 pulokulon','dusun jetak rt 05 rw 04 pulokulon','P','jelapat','2002-01-08','3315064801020007','D3 Administrasi Bisnis','+62 851-7318-1768','089509650330','siwiirmaaa8@gmail.com','Islam','mimin','joko susanto','L','SMA/MA/SMK/Sederajat','SMA NEGERI 1 PURWODADI','Bulanan','Google','santana bakery','kasir','','','2025-01-11 15:36:45'),(250006,'Kelas Karyawan','ACHMAD HSUAENI HARIS','Universitas Pandanaran (UNPAND)','GANJURAN, RT 03 RW.08 SUKOREJO, KECAMATAN MERTOYUDAN KAB. MAGELANG','GANJURAN, RT 03 RW.08 SUKOREJO, KECAMATAN MERTOYUDAN KAB. MAGELANG','L','MAGELANG','1986-07-27','3308102707860002','S1 Arsitektur','081392895631','081392895631','harishusaeni110@gmail.com','Islam','SUWANTI','MUH SAIL','L','SMA/MA/SMK/Sederajat','SMK N 1 MAGELANG','Semesteran','Google','CV. SETIYA BAKTHI','WAKIL DIREKTUR','','081392895631','2025-01-16 08:39:03'),(250007,'Kelas Karyawan','PURBO WICAKSONO','Universitas Pandanaran (UNPAND)','Bungkusrejo,RT:007/RW:3,Tegalrejo,Tegalrejo,Kabupaten Magelang','Bungkusrejo,RT:007/RW:3,Tegalrejo,Tegalrejo,Kabupaten Magelang','L','Kabupaten Magelang','1990-10-03','3308101003900003','S1 Teknik Sipil','082338593439','087778267465','purbowicaksono1990@gmail.com','Islam','Sumaryati','Rajiman','L','SMA/MA/SMK/Sederajat','SMKN 1 Magelang','Bulanan','Google','PT.Niaga Bersama Persada','Pelaksana Lapangan','','(021)88966887','2025-01-18 18:21:01'),(250008,'Kelas Karyawan','MANSUR SAIFUDIN','Universitas Pandanaran (UNPAND)','Dk. Sirahan RT 007 RW 001','Dk. Sirahan RT 007 RW 001','L','Jepara','1992-04-23','332015230492','D3 Teknik Mesin','081280856870','082133452777','mansyur.43@gmail.com','Islam','ngatiyem','mat kosim','XXL','SMA/MA/SMK/Sederajat','SMA Muhammadiyah Bangsri','Bulanan','Google','','','','','2025-01-20 09:19:32'),(250009,'reguler','MUHAMMAD CHAEZA ADITYA','Universitas Pandanaran (UNPAND)','Kab. Pekalongan, kec. kajen, ds. gandarum','Kabupaten Pekalongan','L','Pekalongan','2002-09-27','3326082709020001','S1 Manajemen','085868782722','085848190900','Chezaaditya@gmail.com','Islam','Damiri','Misyanto','L','SMA/MA/SMK/Sederajat','SMK Maarif Nu Kajen','Bulanan','Google','CV. Hrv Planner Consultant','Obe rangkap staf admin','','(024) 76481050','2025-01-23 03:45:31'),(250010,'Kelas Karyawan','RAJ DAVIQ','Universitas Pandanaran (UNPAND)','jalan merpati dalam rt 3 rw 9','jalan merpati dalam rt 3 rw 9','L','semarang','2000-04-27','3374012704000003','S1 Arsitektur','08882996173','0895360321243','rajdaviq1@gmail.com','Islam','sartifah','akhsan','L','D3/Sederajat','politeknik industri furnitur dan pengolahan kayu','Bulanan','Teman/Keluarga','cv asia furnindo','product engineering','','-','2025-01-29 06:18:24'),(250011,'Kelas Karyawan','MUHAMAD RIFKI ASAD','Universitas Pandanaran (UNPAND)','Gatak RT 002 RW 003 Mungkid Magelang','Gatak RT 002 RW 003 Mungkid Magelang','L','Jayapura','1997-03-14','8101060701970001','S1 Manajemen','082259479175','085329374554','muhamadrifkiasad@gmail.com','Islam','Imas Masitoh','Empar Supardi','L','SMA/MA/SMK/Sederajat','SMK PELAYARA PUTRA SAMUDERA SORONG','Semesteran','Facebook','PT.SARANABHAKTI TIMUR','Driver','','082192630623','2025-02-02 23:05:42'),(250012,'reguler','ANGGA SETIAWAN','Universitas Pandanaran (UNPAND)','DUSUN KAMAN RT 004/005 DESA SUGIHAN KECAMATAN TOROH KABUPATEN GROBOGAN PROVINSI JAWA TENGAH','DUSUN KAMAN RT 004/005 DESA SUGIHAN KECAMATAN TOROH KABUPATEN GROBOGAN','L','GROBOGAN','2002-01-08','3315040801020004','S1 Teknik Sipil','+62 822-2646-2611','+62 857-8615-4713','anggasetiawan080102@gmail.com','Islam','WINARTI','HARNO','L','SMA/MA/SMK/Sederajat','SMKN 2 PURWODADI','Bulanan','Instagram','','','','','2025-02-03 02:22:38'),(250014,'Kelas Karyawan','YAKOBUS A MAUSE','Universitas Pandanaran (UNPAND)','Naumang','Kupang','L','Naumang','2025-10-05','5305050510010001','S1 Teknik Sipil','08155271679','085847102969','jhackmaushe@gmail.com','Kristen Protestan','Asnat Mowata','Omri Mause','L','D3/Sederajat','Akademi teknik Kupang','Semesteran','Google','','','','','2025-02-17 06:18:40'),(250015,'reguler','ERWIN MARLANTINO','Universitas Pandanaran (UNPAND)','Jln kebon sirih 3 no 137 5b','Jln kebon sirih 3 no 137 5b Rt 05 Rw 08 bandung','L','Prabumulih','1978-10-24','1674022410780002','S1 Teknik Sipil','087769001910','085795053331','erwinnina1978@gmail.com','Islam','Maryamah','M. Yaman','L','SMA/MA/SMK/Sederajat','Sma pasundan 2 bandung','Semesteran','Brosur','Pt cscods','Spv ','','082380136700','2025-02-18 07:53:18'),(250016,'reguler','ANNISA DEWI SAFITRI','Universitas Pandanaran (UNPAND)','KEJI','JL. Bima Sakti Raya, Desa Keji','P','SEMARANG','2006-12-27','3322076712060001','S1 Akuntansi','+62 812-2978-2879','085861980903','safitri20567@gmail.com','Islam','Henni Yuniarti putri','Suparno','M','SMA/MA/SMK/Sederajat','SMK N H.MOENADI UNGARAN','Bulanan','Teman/Keluarga','','','','','2025-02-18 08:38:51'),(250017,'reguler','ANNISA DEWI SAFITRI','Universitas Pandanaran (UNPAND)','KEJI','JL. Bima Sakti Raya, Desa Keji','P','SEMARANG','2006-12-27','3322076712060001','S1 Akuntansi','+62 812-2978-2879','085861980903','safitri20567@gmail.com','Islam','Henni Yuniarti putri','Suparno','M','SMA/MA/SMK/Sederajat','SMK N H.MOENADI UNGARAN','Bulanan','Teman/Keluarga','','','','','2025-02-18 08:45:30'),(250018,'Kelas Karyawan','YAINI','Universitas Pandanaran (UNPAND)','wonoplumbon rt001 rw001','wonoplumbon rt001 rw001','L','SEMARANG','1986-08-30','3374143008860001','S1 Akuntansi','085799199333','085799199333','zenykunienk@gmail.com','Islam','SAMRONAH','SUKIMAN','S','SMA/MA/SMK/Sederajat','SMA 13 SEMARANG','Bulanan','Facebook','PT SAMWON BUSANA INDONESIA','Admin produksi','','0247616980','2025-02-21 04:02:39'),(250019,'Kelas Karyawan','MARIA ANNA MANIBUI','Universitas Pandanaran (UNPAND)','WESIRI','Wesiri','P','Kabupaten Teluk Bintuni','1998-01-04','9206014401980001','D3 Administrasi Bisnis','0822-4756-5119','0812-4893-8181','mariaannamanibui04@qmail.com','Kristen Protestan','Amilda Manikrowi','Isidorus Manibuy','S','SMA/MA/SMK/Sederajat','SMA NEGERI 01 BINTUNI','Bulanan','Facebook','BPBD Kabupaten Teluk Bintuni','Rehabilitasi dan Rekonstruksi','','','2025-02-23 15:16:29'),(250020,'Kelas Karyawan','Galang Abrar rafi','Universitas Pandanaran','Kebonbatur Mranggen Demak','Gaharu timur dalam no 133 Banyumanik Semarang','L','Kota Tangerang','2002-09-10','3374121009020003','S1 Manajemen','081938022368','081391858726','galangabrorrofi@gmail.com','Islam','Nurwihayati','Yusno bumulo','XL','SMA/MA/SMK/Sederajat','Ma Al Ghazali','Bulanan',NULL,NULL,NULL,NULL,NULL,'2025-02-28 02:05:14'),(250021,'Kelas Karyawan','Fani Aprida Puspita','Universitas Pandanaran','Desel rt 01 rw 03 sadeng Gunungpati semarang','Desel rt 01 rw 03 sadeng Gunungpati semarang','P','Semarang','2000-04-21','3374126104000001','S1 Manajemen','085876197436','083842462699','fanipuspita37@gmail.com','Islam','Trimoah','Midi','XL',NULL,'Ma Nurul Huda','Bulanan','Instagram',NULL,NULL,NULL,NULL,'2025-02-28 07:15:28'),(250022,'Kelas Karyawan','SHOFIYYATU SHOBRINA','Universitas Pandanaran','JL. LAMSARI RT 02/ RW 01 GEDAWANG, BANYUMANIK, SEMARANG','JL. LAMSARI RT 02/ RW 01 GEDAWANG, BANYUMANIK, SEMARANG','P','SEMARANG','1999-12-17','3374115712990001','S1 Akuntansi','081325103019','085325401887','shofiyyatusbrna@gmail.com','Islam','NUR CAHYATI','M. SAFRON','M','D3/Sederajat','POLITEKNIK NEGERI SEMARANG','Bulanan','Google',NULL,NULL,NULL,NULL,'2025-03-01 09:47:01'),(250023,'Kelas Karyawan','fita monika','Universitas Pandanaran','rusunawa karangroto blok c no.315 rt 02 rw 013','rusunawa karangroto blok c no.315 rt 02 rw 013','P','semarang','1994-12-04','3374024412940001','D3 Administrasi Bisnis','085624304237','085796822078','vitamonica24@gmail.com','Islam','sri rahayu','mukmin','L','Paket C','pkbm srikandi','Bulanan','Instagram',NULL,NULL,NULL,NULL,'2025-03-02 10:00:59'),(250024,'Kelas Karyawan','Galih Sutyya','Universitas Pandanaran','Kp sukahurip Ds kudadepa Kec Suka hening Kab tasikmalaya','Karawang','L','Kuningan','2004-05-28','3206332805040002','D3 Teknik Kimia','081222103612','081288451803','galihsutia92992@gmail.com','Islam','Lilis','sutisna','L','SMA/MA/SMK/Sederajat','MAN 3 TASIKMALAYA','Bulanan','Brosur','PT pindo Deli 2',NULL,'Kutamekar,karawang',NULL,'2025-03-06 04:42:08'),(250025,'Kelas Karyawan','DESI FITRI NURJANAH','Universitas Pandanaran','Desa Grinting','BREBES','P','Brebes','2003-12-17','3329144702020005','S1 Manajemen','8895412768297','0895412691414','desif5162@gmail.com','Islam','Darti','Carimad','XL','SMA/MA/SMK/Sederajat','SMK N 01 BULAKAMBA','Bulanan','Instagram','PT BINTANG INDOKARYA GEMILANG',NULL,'Desa tengguli kec.tanjung kab.brebes',NULL,'2025-03-06 12:26:17'),(250026,'Kelas Karyawan','Fadillah Argo Jati Wibawono','Universitas Pandanaran','Jl.Bukit Umbul RT 05 RW 04 Kel.Sumurboto Kec.Banyumanik','Semarang','L','Semarang, 18 Januari 2006','2006-01-18','3374111801060005','D3 Teknik Mesin','081326261363','081234595682','rafliano26@gmail.com','Islam','Ismiyati','Sularso','L','SMA/MA/SMK/Sederajat','Universitas Pandanaran','Bulanan','Instagram','Perta Daya Gas',NULL,'Jl. Ronggowarsito No.1, Tj. Mas, Kec. Semarang Utara, Kota Semarang, Jawa Tengah 50134',NULL,'2025-03-07 01:50:45'),(250027,'Kelas Karyawan','Mochammad Nafi Syahrul Ramadhan','Universitas Pandanaran','Jalan Lamper Tengah 1 No 560 Semarang','Jalan Lamper Tengah 1 No. 560 Semarang','L','Kota Semarang','2002-11-05','3374070511020004','D3 Teknik Mesin','082229855601','089513791484','nafiramadan55@gmail.com','Islam','Umi Nur Zaemah','Yuli Setiawan','L','SMA/MA/SMK/Sederajat','Sma Islam Sultan Agung 1','Semesteran','Google',NULL,NULL,NULL,NULL,'2025-03-10 05:04:02'),(250028,'Kelas Karyawan','Nazila Putri Wibowo','Universitas Pandanaran','Randusari Pos II No. 118','Randusari Pos II Atas No. 115, Semarang Selatan;50244','P','Kota Semarang','2007-04-08','3374074804070005','S1 Manajemen','082223119845','089666648793','zila.workmail@gmail.com','Islam','Siti Aryati','Edy Sarwono','L','SMA/MA/SMK/Sederajat','SMKN 4 Semarang','Semesteran','Teman/Keluarga',NULL,NULL,NULL,NULL,'2025-03-18 09:53:33'),(250029,'Kelas Karyawan','Messy Rahayuningsih','Universitas Pandanaran','Jl Candisari, Kr Boyo RT 1 RW 1','Jl Candisari, Kr Boyo RT 1 RW 1','P','Demak','2006-01-29','3321016901060004','S1 Manajemen','0882008277189','0882005218060','xxymssyrhyu@gmail.com','Islam','Sajimah','Sugiyanto','L',NULL,'MA NU MRANGGEN','Semesteran','Instagram',NULL,NULL,NULL,NULL,'2025-03-19 05:44:28'),(250030,'Kelas Karyawan','aik kusuma adhi pamungkas','Universitas Pandanaran','ngabean rt 001 rw 002 kecamatan boja kabupaten kendal','pakintelan rt 04 rw 03 gunungpati kota semarang','L','semarang','1999-10-27','3324072710990004','S1 Arsitektur','085174252715','085158812154','aik440461@gmail.com','Islam','sri mutiah alm','kastur kasno','L','SMA/MA/SMK/Sederajat','MA al asror','Bulanan','Instagram','soto ayam pak wito',NULL,'sukorejo gunungpati kota semarang jawa tengah 50221',NULL,'2025-03-27 07:34:30'),(250031,'Kelas Karyawan','IZZATUL PUTRI AMALIA','Universitas Pandanaran','PETE RT 02/RW03, MAJAKSINGI, BOROBUDUR,KAB. MAGELANG, JAWA TENGAH','PETE RT 02/RW03, MAJAKSINGI, BOROBUDUR,KAB. MAGELANG, JAWA TENGAH','P','MAGELANG','2006-01-12','3308025201060001','S1 Teknik Sipil','085726945016','087849191794','petemajaksingi@gmail.com','Islam','YAMINI','MAKTUB','M','SMA/MA/SMK/Sederajat','SMK N 1 MAGELANG','Semesteran','Teman/Keluarga','PT CIPTA NIAGA SEMESTA',NULL,NULL,NULL,'2025-04-03 05:32:37'),(250032,'Kelas Karyawan','Tiwik Anggraini Puspita Sari','Universitas Pandanaran','Dusun Karangasem','Tlogosari','P','Grobogan','2003-12-15','3315025512030003','S1 Manajemen','089504832587',NULL,'tiwikaps@gmail.com','Islam','Murmini','Sumarno','S','SMA/MA/SMK/Sederajat','Smk Yatpi Godong','Bulanan','Instagram','Anytime Fitness Semarang',NULL,'Queen City Mall, Jl. Pemuda No.27-31 Lantai 2, Pandansari, Kec. Semarang Tengah, Kota Semarang, Jawa Tengah 50139',NULL,'2025-04-12 02:45:57'),(250033,'Kelas Karyawan','ELLSHADAY ARROW SUKOCO','Universitas Pandanaran','BSI BLOK G/39 RT/RW 002/012 Kel/Desa PENGASINAN Kecamatan SAWANGAN','GROBOGAN','L','GROBOGAN','2003-07-10','3276031007030005','S1 Teknik Sipil','085716916192','0882006602781','ellrowsoekotjo@gmail.com','Kristen','PARTININGSIH','SUKOCO','L','SMA/MA/SMK/Sederajat','SMA YADIKA 12 LIMO','Bulanan','Teman/Keluarga','Bengkel Sinar Bintang Las',NULL,'Sidorejo, Cabean',NULL,'2025-04-21 06:16:31'),(250034,'Kelas Karyawan','Veri Triono','Universitas Pandanaran','KOMPLEK PERUM PPNC RT 05 RW 05 TEGALKAMULYAN CILACAP SELATAN','Kaliwungu, Kendal','L','Cilacap','2000-11-28','3301212811000001','D3 Teknik Mesin','085799198824','081931698041','veritriono22@gmail.com','Islam','Muji Setyaningsih','Suyatino','L','SMA/MA/SMK/Sederajat','SMK DR SOETOMO CILACAP','Semesteran','Instagram','PT GOLDEN INOVASI INDONESIA',NULL,'Tambak, Wonorejo, Kec. Kaliwungu, Kabupaten Kendal, Jawa Tengah',NULL,'2025-04-23 00:07:13'),(250035,'Kelas Karyawan','PRATAMA HELDY NUR YASIN','Universitas Pandanaran','Dsn GENTONG,RT 014,RW 003,Kel ARGOSARI,Kec JABUNG,MALANG,JAWA TIMUR','Argosari, Kec. Jabung, Kabupaten Malang, Jawa Timur 65155','L','MALANG','2004-04-23','3507182304040003','D3 Teknik Mesin','081553388241','085749512916','pratamaheldy23@gmail.com','Islam','SUSIATI','ROFII','L','SMA/MA/SMK/Sederajat','SMKN6 MALANG','Bulanan','Teman/Keluarga','PT SAPTA INDRA SEJATI',NULL,'JL. Kelanis No.KM 35, Tamiang Layang, Kec. Dusun Tim., Kabupaten Barito Timur, Kalimantan Tengah 73671',NULL,'2025-04-23 02:08:20'),(250036,'Kelas Karyawan','TYA PUSPITASARI','Universitas Pandanaran','Dsn. Mulyoasri , Ds, Sumbermulyo , RT/RW 005/002 . Kec. Pesanggaran , Banyuwangi ,Jawa Timur','JAWA TIMUR , BANYUWANGI , PESANGGARAN','P','BANYUWANGI','2004-07-14','3510015407040004','S1 Arsitektur','082334168799','85232122903','tyapuspitasari60@gmail.com','Hindu','WIDYA','SUNARTO','L','SMA/MA/SMK/Sederajat','SMKN 1 GLAGAH','Semesteran','Instagram','THE STEW',NULL,'JL.BANTERANG NO.41 , BANYUWANGI',NULL,'2025-04-24 06:56:58'),(250037,'Kelas Karyawan','Mita Aprilia','Universitas Pandanaran','Jl. Singotoro 6a rt2 rw4','Semarang','P','Semarang','2007-04-27','3374086704070001','S1 Teknik Sipil','083846294193','085786583621','apriliametaa0o@gmail.com','Islam','Sumiyati','Mulyoko','L','S1/D4/Sederajat','SMK MUHAMMADIYAH 2 SEMARANG','Bulanan','Teman/Keluarga',NULL,NULL,NULL,NULL,'2025-05-03 14:36:33'),(250038,'Kelas Karyawan','MARISUMAN','Universitas Pandanaran','JL KARANG JAWA NO 35 RT 005 RW 000','JL KARANG JAWA NO 35 RT 005 RW 000','L','SUKAREJO','1992-12-31','1223060703920006','S1 Teknik Sipil','082148008505','082180309086','marisuman99@gmail.com','Islam','LASNI','PUJIONO','XL','SMA/MA/SMK/Sederajat','SMK SWASTA DWI GUNA KAMPUNG PAJAK','Semesteran','Instagram','RDMP BALIKPAPAN JO',NULL,'Jl. Bongas I No. 583 Kel. Karang Jati,  Kec. Balikpapan Tengah Kota Balikpapan, Kalimantan Timur, 76123 Indonesia',NULL,'2025-05-08 01:55:29'),(250039,'Kelas Karyawan','KHOLIFAHTUL EFLIANI','Universitas Pandanaran','Ds. Puguh,Rt02/Rw03, Kec. Pegandon, Kab. Kendal, Jawah Tengah','Ds. Puguh Rt02/Rw03, Kec. Pegandon, Kab. Kendal, Jawah Tengah','P','Kendal','2002-07-03','3324104307020003','D3 Teknik Mesin','081392012274','0895622137437','efliani1231@gmail.com','Islam','RASINI','SSUDARIYONO','L','SMA/MA/SMK/Sederajat','SMK ISLAM SALAKBROJO','Bulanan','Instagram','Pt Mas Arya Indonesia semarang',NULL,'Jl. Tugu wijaya VI,No. 07, Kawasan Industri Wijayakusuma Raya,Semarang,Provinsi Jawah Tengah, Indonesia',NULL,'2025-05-09 09:11:32'),(250040,'Kelas Karyawan','ROY PESTATUA','Universitas Pandanaran','Jl. Pepaya No. 21 RT.01 / RW.07 DURI RIAU','Jl. Pepaya No. 21 RT.01 / RW.07 DURI RIAU','L','Duri','1988-04-01','1403130104880003','D3 Teknik Mesin','081270919539','085278254258','pesta_roy@yahoo.co.id','Kristen','RISMA SIMANJUNTAK','A. MANIK (ALM)','XXL','SMA/MA/SMK/Sederajat','SMAN1 MANDAU','Bulanan','Facebook','POWERCHINA',NULL,'GEDUNG TAMAN ANGGREK JAKARTA',NULL,'2025-05-20 09:49:38'),(250041,'Kelas Karyawan','MAHMUD HIDAYAT','Universitas Pandanaran','KP SUKAWANGI I RT 002/RW 002 Desa WANASALAM','KP SUKAWANGI I RT 002/RW 002 Desa WANASALAM','L','Lebak','1992-05-07','3602211705920003','S1 Manajemen','085846175512','085845175512','Mahmudhidayat92@gmail.com','Islam','Aan kusmiati','Ujang','M','SMA/MA/SMK/Sederajat','SMA Negeri 1 Wanasalam','Bulanan','Instagram',NULL,NULL,NULL,NULL,'2025-05-23 15:15:29'),(250042,'Kelas Karyawan','Alfi Nafisa','Universitas Pandanaran','Dsn Seseh RT 02 RW 09 Ngadisepi Gemawang Temanggung','Dsn Seseh RT 02 RW 09 Ngadisepi Gemawang Temanggung','P','Temanggung','2005-10-06','3323204610050001','S1 Akuntansi','085194533806','085641918380','alfinafisa22b@gmail.com','Islam','Aswitri','Ngatijo','S','SMA/MA/SMK/Sederajat','SMKN 2 TEMANGGUNG','Bulanan','Google',NULL,NULL,NULL,NULL,'2025-05-30 13:46:12'),(250043,'Kelas Karyawan','NAILA ANGGITA RAMADANI','Universitas Pandanaran','Jln. Tanjungsari lll RT 08 RW 02','Jln. Tanjungsari lll RT 08 RW 02','P','jakarta','2004-11-08','3314154811050002','S1 Akuntansi','083134014606','085867123235','nailaanggita8@gmail.com','Islam','sutini','sukadi','M','SMA/MA/SMK/Sederajat','smk widya praja','Semesteran','Teman/Keluarga','PT Erlangga Edi Laboratorium',NULL,'jln.murbei',NULL,'2025-06-04 05:47:14'),(250044,'Kelas Karyawan','dwi ardi saputra','Universitas Pandanaran','jl. a. yani no 452 kupatan','jl. a. yani no 452 kupatan','L','magelang','1998-10-26','3308202610980005','S1 Teknik Sipil','085643128095','085326052161','dwi4rd1@gmail.com','Islam','wartini','juwandi','M','SMA/MA/SMK/Sederajat','smk n 1 magelang','Bulanan','Teman/Keluarga','cv pilar tritama',NULL,'perum pulau mas wates',NULL,'2025-06-12 09:21:00'),(250045,'Kelas Karyawan','Nurfita Sari','Universitas Pandanaran','Malei Tojo, kecamatan Tojo barat, kabupaten Tojo una-una Sulawesi tengah','Matialemba, kecamatan pamona timur, kabupaten Poso Sulawesi tengah','P','Malei Tojo','1998-10-01','7209074110980007','S1 Akuntansi','082345753411','082248412428','nurfitas07@gmail.com','Islam','Roslin','Arfin Lajijo','M','SMA/MA/SMK/Sederajat','SMK NEGERI 1 TOJO BARAT','Semesteran','Google','PT.SAWIT JAYA ABADI 2 POSO',NULL,'Matialemba, kecamatan pamona timur, kabupaten Poso Sulawesi tengah',NULL,'2025-06-19 04:18:06'),(250046,'Kelas Karyawan','Raespati Prajasa','Universitas Pandanaran','Jl Karangkamulyan Gg Mrica no. 12','Jl Karangkamulyan Gg Mrica no. 12','L','Serang','1986-03-02','3305190203860003','D3 Teknik Mesin','081225825681','08156959100','raespati@gmail.com','Islam','Esti Yuningsih','Alm. Suradja','XL','SMA/MA/SMK/Sederajat','MA Ali Maksum','Bulanan','Facebook',NULL,NULL,NULL,NULL,'2025-06-20 04:48:56'),(250047,'Kelas Karyawan','DYTA PRATIWI','Universitas Pandanaran','DSN. KENTANGAN RT001/RW002, DESA BAYU, KEC. SONGGON, KAB. BANYUWANGI','DSN. KENTANGAN RT001/RW002, DESA BAYU, KEC. SONGGON, KAB. BANYUWANGI','P','KAB. BANYUWANGI','2005-05-19','3510195905050001','S1 Arsitektur','085234202557','085784043932','dythapratiwi67@gmail.com','Islam','JUMA\'ATI','PRAMONO','M','SMA/MA/SMK/Sederajat','SMKN 1 GLAGAH BANYUWANGI','Bulanan','Teman/Keluarga','CUBICLE STUDIO',NULL,'BANYUWANGI',NULL,'2025-06-26 03:57:19'),(250048,'Kelas Karyawan','SYAMSUL ARIFIN','Universitas Pandanaran','Ngemplak undaan kudus','Ngemplak','L','Kudus','1995-04-27','3319042704950001','S1 Arsitektur','0895426231122','08980494573','arifinputra27045@gmail.com','Islam','Suparni','Faqih','L','SMA/MA/SMK/Sederajat','MA NU ASSALAM','Semesteran','Google',NULL,NULL,NULL,NULL,'2025-06-29 13:55:06'),(250049,'Kelas Karyawan','M. Rosyiq Alfajar','Universitas Pandanaran','Rt.02 Rw.01 Desa Sendang kec. Tersono kab. Batang kode pos 51272','Rt.02 / 01 Desa srndang kec. Tersono kab. Batang','L','Batang','2006-09-11','3325061109060001','S1 Kewirausahaan','082242187426','081326455331','sajaetik8@gmail.com','Islam','Siti etik shahana','Eko haryanto',NULL,'SMA/MA/SMK/Sederajat','SMK Ma\'arif NU Bawang','Semesteran','Teman/Keluarga',NULL,NULL,NULL,NULL,'2025-06-30 00:52:21'),(250050,'Kelas Karyawan','Movich Adhi Nugroho','Universitas Pandanaran','Jl.Dinar Mas Utara III/36 Meteseh Tembalang Semarang','Perumahan Griya Nusa Asri Blok D2 No.10 Kayon Batursari Mranggen Demak','L','Semarang','2006-12-20','3374102012060007','S1 Arsitektur','087828113578','087760532789','movichnugroho123@gmail.com','Islam','Sari Fajarwati','Danu Umboro','XXL','SMA/MA/SMK/Sederajat','SMK Negeri 3 Semarang','Bulanan','Teman/Keluarga','CV.Sarana Wijaya',NULL,'Jl.Cinde Barat IX/15 Jomblang Candisari Semarang',NULL,'2025-07-03 12:12:12'),(250051,'Kelas Karyawan','Nurul hidayah','Universitas Pandanaran','Bedono Sayung Demak','Bedono Sayung Demak','P','Demak','2005-02-11','3321045102050002','S1 Akuntansi','081575081760','088227646341','nh0749485@gmail.com','Islam','Jumroh','Kumaidi','M','SMA/MA/SMK/Sederajat','SMK Al kautsariyyah','Bulanan','Instagram',NULL,NULL,NULL,NULL,'2025-07-05 09:44:41'),(250052,'Kelas Karyawan','Achmad Daafiq Azhari','Universitas Pandanaran','JL. PANJAITAN/ 86 SIROTO','Ungaran Timur,susukan siroto, Rt 02/Rw 02','L','Kab Semarang','2006-12-14','3322181412060002','D3 Teknik Mesin','085740413133','087854022017','achmaddaafiq@gmail.com','Islam','Suwarni','Mulyamto','L','SMA/MA/SMK/Sederajat','SMKN H MOENADI UNGARAN','Semesteran','Teman/Keluarga',NULL,NULL,NULL,NULL,'2025-07-14 04:54:05'),(250053,'Kelas Karyawan','TRIYONO','Universitas Pandanaran','Desa Kwigaran RT 02 RW 04, Kecamatan Kesesi, Kabupaten Pekalongan','Desa Kwigaran RT 02 RW 04, Kecamatan Kesesi, Kabupaten Pekalongan','L','Kab. Pekalongan','1990-08-08','3326090808900003','D3 Teknik Mesin','085777269663','085879864948','triyono.sh16@gmail.com','Islam','Sumirah','Kuat Santoso','XL','SMA/MA/SMK/Sederajat','SMAN 1 KESESI','Bulanan','Facebook',NULL,NULL,NULL,NULL,'2025-07-29 09:20:21'),(250054,'Kelas Karyawan','Jimmy piantoka','Universitas Pandanaran','Cangkiran Rt.002 Rw.002 cangkiran mijen Kota semarang','Balikpapan','L','Semarang','1993-02-25','3374142502930001','S1 Manajemen','085727729446','082243468437','Jimmypiantoka@gmail.com','Islam','Suanah','Sunarto','L','SMA/MA/SMK/Sederajat','Smk palapa','Semesteran','Facebook','Pt.wahyu agung',NULL,'Surabaya',NULL,'2025-08-01 12:32:42'),(250055,'Gelombang III','adskuliah karyawanid','Universitas Pandanaran','Jl Ir H Juanda No71 Pisangan Kec Ciputat','Jl Ir H Juanda No71 Pisangan Kec Ciputat','L','depok','2025-08-05','0858803670734567','S1 Kewirausahaan','087804681458','085880367073','farhanyuswaa@gmail.com','Islam','test','test','XL','SMA/MA/SMK/Sederajat','test','Bulanan','Instagram','kuliah karyawan',NULL,NULL,NULL,'2025-08-04 02:02:44');
/*!40000 ALTER TABLE `daftar` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `failed_jobs`
--

DROP TABLE IF EXISTS `failed_jobs`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `failed_jobs` (
  `id` bigint unsigned NOT NULL AUTO_INCREMENT,
  `uuid` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `connection` text COLLATE utf8mb4_unicode_ci NOT NULL,
  `queue` text COLLATE utf8mb4_unicode_ci NOT NULL,
  `payload` longtext COLLATE utf8mb4_unicode_ci NOT NULL,
  `exception` longtext COLLATE utf8mb4_unicode_ci NOT NULL,
  `failed_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  UNIQUE KEY `failed_jobs_uuid_unique` (`uuid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `failed_jobs`
--

LOCK TABLES `failed_jobs` WRITE;
/*!40000 ALTER TABLE `failed_jobs` DISABLE KEYS */;
/*!40000 ALTER TABLE `failed_jobs` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `images`
--

DROP TABLE IF EXISTS `images`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `images` (
  `image_id` int NOT NULL AUTO_INCREMENT,
  `kategori` varchar(200) NOT NULL,
  `file` varchar(100) NOT NULL,
  `path` varchar(100) NOT NULL,
  `active` enum('1','0') NOT NULL,
  `created_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`image_id`)
) ENGINE=InnoDB AUTO_INCREMENT=52 DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `images`
--

LOCK TABLES `images` WRITE;
/*!40000 ALTER TABLE `images` DISABLE KEYS */;
INSERT INTO `images` VALUES (33,'event','40kegiatan.webp','images/media/','0','2024-03-13 10:45:31'),(34,'Event Kampus','69wisudake15-unpand.webp','images/media/','1','2024-06-29 10:42:43'),(35,'Fasilitas Kampus','54WhatsApp Image 2024-06-29 at 10.50.20.webp','images/media/','1','2024-06-29 10:51:27'),(36,'','4Untitled design.webp','images/media/','1','2024-07-27 11:19:03'),(37,'','6Desain tanpa judul (20).webp','images/media/','1','2024-07-27 11:20:04'),(38,'','69sgs k2.webp','images/media/','1','2024-07-27 11:24:28'),(39,'','57Prospek Kerja Jurusan S1 Manajemen (94).webp','images/media/','1','2024-09-25 10:49:21'),(40,'Fasilitas Kampus','212013-06-09 10.14.06.webp','images/media/','1','2025-02-14 08:58:12'),(41,'Fasilitas Kampus','51WhatsApp Image 2024-02-01 at 14.50.23_c02a78e3.webp','images/media/','1','2025-02-14 09:38:16'),(42,'Fasilitas Kampus','9712.webp','images/media/','1','2025-02-14 09:38:33'),(43,'Kegiatan Mahasiswa','73DSCF6730.webp','images/media/','1','2025-02-14 09:39:22'),(44,'Fasilitas Kampus','9212.webp','images/media/','1','2025-02-14 09:39:42'),(45,'Event Kampus','59IMG-20230718-WA0001.webp','images/media/','1','2025-02-14 10:16:48'),(46,'Event Kampus','40image (2).webp','images/media/','1','2025-02-14 10:17:01'),(47,'Event Kampus','90IMG-20230718-WA0002.webp','images/media/','1','2025-02-14 10:17:33'),(48,'Kegiatan Mahasiswa','13IMG-20230916-WA0014.webp','images/media/','1','2025-02-14 10:18:39'),(49,'Kegiatan Mahasiswa','5IMG-20230916-WA0015.webp','images/media/','1','2025-02-14 10:18:59'),(50,'Kegiatan Mahasiswa','48IMG-20230916-WA0009.webp','images/media/','1','2025-02-14 10:19:09'),(51,'Kegiatan Mahasiswa','56WhatsApp Image 2024-01-30 at 11.33.18_361b7018.webp','images/media/','1','2025-02-14 10:19:26');
/*!40000 ALTER TABLE `images` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `kontak`
--

DROP TABLE IF EXISTS `kontak`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `kontak` (
  `kontak_id` int NOT NULL AUTO_INCREMENT,
  `nama` varchar(100) NOT NULL,
  `no_telp` varchar(100) DEFAULT NULL,
  `email` varchar(100) DEFAULT NULL,
  `alamat` text NOT NULL,
  `pesan` text NOT NULL,
  `created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `updated_at` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`kontak_id`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `kontak`
--

LOCK TABLES `kontak` WRITE;
/*!40000 ALTER TABLE `kontak` DISABLE KEYS */;
INSERT INTO `kontak` VALUES (1,'Movie Clip test','083183262301','admin@gmail.com','Jl. Kenanga 3 no.74 RT 03 RW 05 Kel.Depok Jaya Kec. pancoran mas','sad','2024-11-26 00:34:41','2024-11-26 00:34:41'),(2,'Muhamad Ilham Mubarrok','081389963530','kagamayta721@gmail.com','JL. KP. SAWAH DALAM NO.31','asdasdasd','2024-12-24 02:57:27','2024-12-24 02:57:27'),(3,'Muhamad Ilham Mubarrok','081389963530','kagamayta721@gmail.com','JL. KP. SAWAH DALAM NO.31','asdasdasd','2024-12-24 02:57:37','2024-12-24 02:57:37');
/*!40000 ALTER TABLE `kontak` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `kurikulum`
--

DROP TABLE IF EXISTS `kurikulum`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `kurikulum` (
  `id_kurikulum` int NOT NULL AUTO_INCREMENT,
  `jurusan` varchar(200) COLLATE utf8mb4_unicode_ci NOT NULL,
  `file` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL,
  PRIMARY KEY (`id_kurikulum`)
) ENGINE=InnoDB AUTO_INCREMENT=7 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `kurikulum`
--

LOCK TABLES `kurikulum` WRITE;
/*!40000 ALTER TABLE `kurikulum` DISABLE KEYS */;
/*!40000 ALTER TABLE `kurikulum` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `menu`
--

DROP TABLE IF EXISTS `menu`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `menu` (
  `menu_id` int NOT NULL AUTO_INCREMENT,
  `submenu_id` int NOT NULL DEFAULT '0',
  `menu` varchar(30) DEFAULT NULL,
  `url` varchar(500) DEFAULT NULL,
  `urutan` tinyint NOT NULL,
  `active` enum('1','0') NOT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`menu_id`)
) ENGINE=InnoDB AUTO_INCREMENT=82 DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `menu`
--

LOCK TABLES `menu` WRITE;
/*!40000 ALTER TABLE `menu` DISABLE KEYS */;
INSERT INTO `menu` VALUES (2,0,'Biaya Kuliah','#',5,'1',NULL),(4,0,'Daftar Online','pendaftaran',4,'1',NULL),(7,0,'Akademik','#',3,'1',NULL),(8,0,'Home','./',1,'1',NULL),(10,0,'Galeri','index.php?m=galeri',6,'1',NULL),(26,0,'Tentang','#',2,'1',NULL),(28,26,'Sejarah Singkat','sejarah-singkat',2,'1',NULL),(30,26,'Visi & Misi','visi-misi',4,'1',NULL),(37,10,'Event Kampus','event-kampus',1,'1',NULL),(38,10,'Fasilitas Kampus','fasilitas-kampus',2,'1',NULL),(39,10,'Kegiatan Mahasiswa','kegiatan-mahasiswa',3,'1',NULL),(54,2,'Biaya Kuliah','Biaya-kuliah',1,'1',NULL),(67,7,'Fasilitas Kampus ','13',0,'1',NULL),(68,2,'Brosur','brosur',2,'1',NULL),(71,7,'Sistem Perkuliahan','23',0,'1',NULL),(80,26,'Struktur Organisasi','struktur-organisasi',0,'1','2024-11-13 00:14:16'),(81,7,'Kurikulum','kurikulum',3,'1',NULL);
/*!40000 ALTER TABLE `menu` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `migrations`
--

DROP TABLE IF EXISTS `migrations`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `migrations` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `migration` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `batch` int NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=6 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `migrations`
--

LOCK TABLES `migrations` WRITE;
/*!40000 ALTER TABLE `migrations` DISABLE KEYS */;
INSERT INTO `migrations` VALUES (2,'2014_10_12_100000_create_password_resets_table',1),(3,'2019_08_19_000000_create_failed_jobs_table',1),(4,'2019_12_14_000001_create_personal_access_tokens_table',1),(5,'2024_11_04_063620_create_daftar_table',1);
/*!40000 ALTER TABLE `migrations` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `page`
--

DROP TABLE IF EXISTS `page`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `page` (
  `page_id` int NOT NULL AUTO_INCREMENT,
  `judul` varchar(100) NOT NULL,
  `slug` varchar(200) NOT NULL,
  `short` varchar(250) NOT NULL,
  `isi` text NOT NULL,
  `image` varchar(100) NOT NULL,
  `link` varchar(100) NOT NULL,
  `created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`page_id`)
) ENGINE=MyISAM AUTO_INCREMENT=48 DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `page`
--

LOCK TABLES `page` WRITE;
/*!40000 ALTER TABLE `page` DISABLE KEYS */;
INSERT INTO `page` VALUES (13,'Fasilitas','','Fasilitas Kampus','<p>Kampus&nbsp;Universitas Kepanjen memiliki fasilitas lengkap dan terkini sehingga memudahkan proses belajar mengajar sebagai berikut :</p>\r\n\r\n<ol>\r\n	<li>Kuliah melalui tatap muka serta komunikasi melalui internet.</li>\r\n	<li>Laboratorium yang lengkap dan memadai.</li>\r\n	<li>Ruang Kuliah dilengkapi&nbsp;LCD Proyektor dan Multi media lainnya.</li>\r\n	<li>Perpustakaan&nbsp;menggunakan&nbsp;<em>(Air Conditioner)</em>&nbsp;atau&nbsp;<a href=\"https://id.wikipedia.org/wiki/Penyejuk_udara\">P</a>enyejuk Udara&nbsp;dan menggunakan alat pemantau&nbsp;<em>(cctv).</em></li>\r\n	<li>Tempat ibadah/Musholah yang bersih untuk kesempurnaan ibadah.</li>\r\n	<li>Lokasi kampus strategis, mudah dijangkau dan tersedia tempat parkir.&nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp;</li>\r\n</ol>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>Terima Kasih<br />\r\n<strong>Sekretariat Pendaftaran</strong>&nbsp;<strong>Universitas Kepanjen</strong></p>','','','2025-08-07 03:45:34'),(23,'Sistem Perkuliahan Kelas Karyawan','','Dengan jam kuliah yang fleksibel tersedia kelas sabtu minggu dan kelas shift sangat membantu teman teman yang ingin kuliah namun terkendala jam pekerjaan','<h2>Sistem Perkuliahan</h2>\r\n\r\n<p>Dengan jam kuliah yang sangat fleksibel,&nbsp;menyediakan program kelas karyawan.</p>\r\n\r\n<p>Dengan jadwal kuliah :<br />\r\nKelas Reguler Sore&nbsp;: Senin - Kamis 18.30 - 21.00 WIB<br />\r\nKelas Karyawan&nbsp;: Kamis, Jum&#39;at&nbsp;18.00 - 21.00 Sabtu 09.00 - 17.00 WIB<br />\r\n<br />\r\nJika teman teman memiliki kendala dalam waktu kuliah karena sistem kerja yang shift ataupun kerjaan dengan waktu yang sulit untuk berkuliah, Universitas Kepanjen memilki waktu kuliah yang fleksibel, silahkan dapat menghubungi admin kami untuk konsultasi lebih lanjut.</p>\r\n\r\n<p>&nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp;</p>\r\n\r\n<p>Terima Kasih<br />\r\n<strong>Sekretariat Penerimaan&nbsp;Universitas Kepanjen</strong></p>\r\n\r\n<table border=\"0\" style=\"width:100%\">\r\n	<tbody>\r\n	</tbody>\r\n</table>','','','2025-08-07 03:46:15');
/*!40000 ALTER TABLE `page` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `password_resets`
--

DROP TABLE IF EXISTS `password_resets`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `password_resets` (
  `email` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `token` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  KEY `password_resets_email_index` (`email`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `password_resets`
--

LOCK TABLES `password_resets` WRITE;
/*!40000 ALTER TABLE `password_resets` DISABLE KEYS */;
/*!40000 ALTER TABLE `password_resets` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `personal_access_tokens`
--

DROP TABLE IF EXISTS `personal_access_tokens`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `personal_access_tokens` (
  `id` bigint unsigned NOT NULL AUTO_INCREMENT,
  `tokenable_type` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `tokenable_id` bigint unsigned NOT NULL,
  `name` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `token` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL,
  `abilities` text COLLATE utf8mb4_unicode_ci,
  `last_used_at` timestamp NULL DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `personal_access_tokens_token_unique` (`token`),
  KEY `personal_access_tokens_tokenable_type_tokenable_id_index` (`tokenable_type`,`tokenable_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `personal_access_tokens`
--

LOCK TABLES `personal_access_tokens` WRITE;
/*!40000 ALTER TABLE `personal_access_tokens` DISABLE KEYS */;
/*!40000 ALTER TABLE `personal_access_tokens` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `setting`
--

DROP TABLE IF EXISTS `setting`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `setting` (
  `id_setting` int NOT NULL AUTO_INCREMENT,
  `jenis_set` varchar(20) NOT NULL,
  `nama_set` varchar(200) NOT NULL,
  `nilai_set` varchar(255) NOT NULL,
  `active` enum('1','0') NOT NULL,
  PRIMARY KEY (`id_setting`)
) ENGINE=MyISAM AUTO_INCREMENT=19 DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `setting`
--

LOCK TABLES `setting` WRITE;
/*!40000 ALTER TABLE `setting` DISABLE KEYS */;
INSERT INTO `setting` VALUES (2,'kontak','Telepon','0878-9019-8284','1'),(3,'kontak','Whatsapp','6287818000395','1'),(4,'fb','Facebook','https://www.facebook.com/universitaskepanjen/','1'),(6,'rekening','an Khavid Hasbulloh, PT BRI, Tbk','0924-01-007596-507','1'),(7,'rekening','Khavid Hasbulloh, PT Bank BCA, Tbk','6610-8654-35','1'),(8,'rekening','Khavid Hasbulloh, PT Bank Mandiri Syariah, Tbk','711-2299-666','1'),(9,'ig','Instagram','https://www.instagram.com/k2.univ.kepanjen/','1'),(10,'kampus','nama kampus','Universitas Kepanjen','1'),(11,'biaya formulir','s1','Rp 150.000','1'),(13,'kampus','alamat kampus','Jl. Trunojoyo No.16, Krajan, Panggungrejo, Kec. Kepanjen, Kabupaten Malang, Jawa Timur 65163','1'),(18,'biaya formulir','ners','Rp 150.000','1'),(17,'biaya formulir','d3','Rp 150.000','1');
/*!40000 ALTER TABLE `setting` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `useradmin`
--

DROP TABLE IF EXISTS `useradmin`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `useradmin` (
  `user_id` int NOT NULL AUTO_INCREMENT,
  `username` char(32) DEFAULT NULL,
  `password` varchar(150) DEFAULT NULL,
  `nama` varchar(100) DEFAULT NULL,
  `email` varchar(100) DEFAULT NULL,
  `remember_token` varchar(100) DEFAULT NULL,
  `tipe` char(30) DEFAULT NULL,
  `status` char(10) DEFAULT NULL,
  `lastlogin` datetime DEFAULT NULL,
  PRIMARY KEY (`user_id`)
) ENGINE=InnoDB AUTO_INCREMENT=233 DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `useradmin`
--

LOCK TABLES `useradmin` WRITE;
/*!40000 ALTER TABLE `useradmin` DISABLE KEYS */;
INSERT INTO `useradmin` VALUES (232,'admin','10beaac415ef63830210737bd6d7edb8','Admin Institut Az Zuhra','',NULL,'admin','1',NULL);
/*!40000 ALTER TABLE `useradmin` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `users`
--

DROP TABLE IF EXISTS `users`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `users` (
  `id` bigint unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `kampus` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `gambar` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `logo` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `email` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `email_verified_at` timestamp NULL DEFAULT NULL,
  `password` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `remember_token` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `users_email_unique` (`email`)
) ENGINE=InnoDB AUTO_INCREMENT=13 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `users`
--

LOCK TABLES `users` WRITE;
/*!40000 ALTER TABLE `users` DISABLE KEYS */;
INSERT INTO `users` VALUES (12,'admin Universitas Pandanaran','Universitas Pandanaran','ryiPMh5PNJoUYwSgT9y2XNZrzSzBCFneYaFjMq3v.png','xMr4WNzc5G3O6pBcdVvy1v5JDYA2JU1YXhxQ1SVz.png','admin@gmail.com',NULL,'$2y$10$q8lg220LQ1uyAsu.SlYshOoYOpSafZm2.chYTQ6sapHPxMWNb6c3y',NULL,'2025-04-15 21:18:07','2025-08-02 09:23:03');
/*!40000 ALTER TABLE `users` ENABLE KEYS */;
UNLOCK TABLES;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2025-08-07 13:33:42
