<?php $__env->startSection('title', 'Sejarah'); ?>


<?php $__env->startSection('content'); ?>
<br><br>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => 'Sejarah  Universitas 17 Agustus 1945 Samarinda','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'Sejarah Singkat']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        

        <!-- Konten Teks -->
        <div data-aos="fade-up" class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px]">
            <p>
             Universitas 17 Agustus 1945 Samarinda adalah Perguruan Tinggi swasta yang berkedudukan di Kota Samarinda, Kalimantan Timur yang didirikan oleh Yayasan Pendidikan 17 Agustus 1945 Samarinda pada tanggal 27 September 1963 di Samarinda.  Pada awal berdirinya dengan nama Fakultas Hukum dan Ilmu Kemasyarakatan cabang Untag Jakarta, yang kemudian menjadi Perguruan Tinggi 17 Agustus 1945 Samarinda yang terdiri dari Sekolah Tinggi Ilmu Hukum, Akademi Ilmu Administrasi dan Niaga dan Sekolah Tinggi Teknologi, yang kemudian berubah nama menjadi Universitas   17 Agustus 1945 Samarinda.
<br><br>
Pembinaan Universitas 17 Agustus 1945 Samarinda dilakukan oleh Yayasan Pendidikan    17 Agustus 1945 Samarinda yang didirikan pada hari Senin tanggal 6 Agustus 1962 untuk waktu yang ditentukan lamanya dihadapan Residen RADEN NGABEI PRODJOSUMARTO selaku Notaris di Samarinda, yang kemudian dikukuhkan dengan Akte Nomor : 33 tanggal 6 Agustus 1962.  Selanjutnya mengalami beberapa kali perubahan Dewan Pengurus, masing-masing dengan Akte Pernyataan Rapat sebagai berikut :
<br><br>
<ul>
<li>Akte Keputusan Rapat Nomor 30 tanggal 5 Maret 1984, oleh Notaris sementara Laden Mering, SH.</li>
<li>Akte Keputusan Rapat Nomor 43 tanggal 22 Januari 1986., oleh Notaris Laden Mering, SH.</li>
<li>Akte Keputusan Rapat Nomor 9 tanggal 19 Juli 1987, oleh Notaris Harjo Gunawan.</li>
<li>Akte Keputusan Rapat No. 09 tanggal 10 September 2005 oleh Notaris Lia Cittawan Nanda Gunawan, SH</li>
</ul>
<br><br>
Selanjutnya Pembinaan Universitas 17 Agustus 1945 Samarinda, secara teknis operasional dilakukan melalui Badan Pelaksana Harian Yayasan (BPH) atau Badan Penyelenggaraan Perguruan Tinggi Swasta (BP-PTS), sedang Pembinaan Akademik dilakukan oleh Depdiknas dalam hal ini Dirjen Dikti melalui Koordinator Kopertis wilayah XI Kalimantan.
            </p>

            
        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">
                SEGERA DAFTAR
                </h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
            Bergabunglah bersama  Universitas 17 Agustus 1945 Samarinda dan Bangun Wawasan, Bentuk Karakter, Jadilah Pembawa Perubahan!
        </p>
            <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/pendaftaran']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>DAFTAR SEKARANG <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /home/u768956174/domains/untag-smd.info/UNTAG-SMD/resources/views/Frontend/sejarah.blade.php ENDPATH**/ ?>