<div class="md:h-[827px] h-auto flex flex-col items-center md:flex-row justify-center md:gap-x-[100px] py-[100px] md:py-[100px] px-4 md:px-0 bg-cover bg-no-repeat bg-right md:bg-center"
    style="background-image: url('<?php echo e(asset('./images/background/bg-sambutan.png')); ?>');">
    <div class="flex justify-center md:justify-start w-full md:w-auto flex-col items-center">
    <img src="<?php echo e(asset('./images/sambutan/sambutan.png')); ?>" data-aos="fade-up"
        class="h-auto md:w-[1000px] w-[300px] md:h-[500px] max-w-[450px]" style="border-radius:25px;" alt="<?php echo e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia'); ?>">
    <p style="padding-top: 20px; font-size: 14px; color: #fff; text-align: center; font-family: 'Poppins', sans-serif;">
        <!-- <b>Dendi Afrizal, S.AB., M.Ak, </b> -->
    </p>
</div>
    <div class="flex flex-col md:items-start justify-center items-center w-full md:w-[40%] w-[100%] mt-4 md:mt-0"
        data-aos="fade-up">
        <?php if (isset($component)) { $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSection::class, ['subtext' => ' SAMBUTAN REKTOR '.e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia').'','subtextColor' => '#fff','title' => '','titleColor' => '#fff']); ?>
<?php $component->withName('header-section'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe)): ?>
<?php $component = $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe; ?>
<?php unset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe); ?>
<?php endif; ?>
        <p class="text-justify font-dmsans mb-4 font-inter text-sm md:text-base  normal-case w-[80%]" style="color:#fff" >
            Institut Elkatarie hadir untuk mengitegrasikan Budaya Lokal dengan Islamic religius sehingga banyak kurikulum baru yang kami munculkan yaitu Pendidikan bahasa sasak, Mitigasi Bencana, Ekonomi islam, hingga ke etika sasak.

Keunggulan kuliah di Institut Elkatarie ialah meningkatkan peran Institusi dalam pengabdian masyarakat berbasis Riset.
<br><br>
” ini adalah Institut yang dapat dijangkau oleh semua calon mahasiswa dan mahasiswi apalagi bagi masyarakat yang tidak mampu. Institut Elkatari adalah solusi baginya”.
<br><br>
Lebih lanjut dikatakannya, Institut Elkatarie juga mengembangkan budaya Penelitian pada Civitas Akademik dan masyarakat. Sehingga tujuan yang dihasilkan itu bisa menghasilkan Lulusan yang Kompeten dalam memfasilitasi potensi Lokal dan Ilmu Ke-Islaman.
<br><br>
” Karena kita mengedepankan Riset dalam Kehidupan bermasyarakat dan Peduli terhadap pengembangan masyarakat Madani serta mampu bersaing dalam menghadapi tantangan global, sebab mereka nantinya sudah bisa membangun kerjasama dengan berbagai pihak dan menjadi generasi yang mandiri dan berakhlakulkarimah.”
        </p>
        
        <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/sejarah-singkat']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>BACA SELENGKAPNYA <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
    </div>
</div>
<?php /**PATH /home/u768956174/domains/institut-elkatarie.info/INSTITA/resources/views/Frontend/landingpage/sambutan-section.blade.php ENDPATH**/ ?>