<!DOCTYPE html>
<html lang="id">

<head>
    <!-- Meta tags -->
    <meta charset="utf-8">
    <meta name="description" content="STEI YPAM Cianjur merupakan kampus unggulan dengan program S1 Ekonomi Syariah. Dapatkan pendidikan berkualitas, berbasis nilai islami, dan siap bersaing di dunia kerja." />
    <meta name="keywords" content="STEI YPAM, STEI YPAM Cianjur, kampus Cianjur, kuliah di Cianjur, kampus ekonomi syariah, S1 Ekonomi Syariah, kuliah ekonomi syariah, sekolah tinggi ekonomi islam, kampus islam di Cianjur, perguruan tinggi Cianjur, kuliah murah Cianjur, kampus terbaik Cianjur, pendaftaran mahasiswa baru Cianjur, kampus swasta Cianjur, kuliah sambil kerja, kampus karyawan Cianjur, pendidikan tinggi ekonomi syariah, jurusan ekonomi syariah, kampus islami, universitas di Cianjur, sekolah tinggi di Cianjur, pendidikan berbasis syariah, kuliah fleksibel, kampus dengan biaya terjangkau, kuliah online Cianjur, kuliah kelas karyawan, STEI YPAM resmi, kampus akreditasi Cianjur" />

    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />

    <title>home &mdash; STEI YPAM (Kelas Karyawan)</title>
    <meta property="og:title" content="STEI YPAM (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="https://steiypam.info">
    <meta property="og:image" content="https://steiypam.info/images/background/hero1.png">
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description"
        content="STEI YPAM adalah pilihan terbaik untuk pendidikan tinggi di Cianjur. Dengan program studi unggulan seperti S1 Ekonomi Syariah, kampus ini menawarkan pendidikan berkualitas dengan dukungan fasilitas modern dan pengajar profesional. Lokasi strategis di Jakarta menjadikan kampus ini pilihan utama bagi mahasiswa lokal dan nasional.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="STEI YPAM | STEI YPAM (Kelas Karyawan)">
    <meta name="twitter:description"
        content="Ingin kuliah sambil tetap bekerja? STEI YPAM menyediakan fleksibilitas waktu dengan kelas reguler dan kelas karyawan. Program studi seperti S1 Ekonomi Syariah, dirancang untuk mendukung kesuksesan karier Anda dengan biaya terjangkau.">
    <meta name="twitter:domain" content="https://steiypam.info/">
    <meta name="twitter:image:src" content="https://steiypam.info/images/background/hero1.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="STEI YPAM | Kuliah Karyawan K2" />
    <meta name="msapplication-TileColor" content="#F96D1E" />
    <meta name="theme-color" content="#F96D1E" />

    <meta name="google-site-verification" content="" />

    <link rel="apple-touch-icon" sizes="57x57" href="/images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="/images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="/images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="/images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="/images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="/images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"  href="/images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="/images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/images/favicons/favicon-16x16.png">
    <link rel="manifest" href="/images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="/images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">    


    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@400;600&family=DM+Sans:wght@400;700&display=swap"
        rel="stylesheet">
    <link href="./css/app.css" rel="stylesheet">
    
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css" />
    
    <link href="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css">
    <!-- Google tag (gtag.js) -->
<script async src="https://www.googletagmanager.com/gtag/js?id=G-TLMBHV8MEC"></script>
<script>
  window.dataLayer = window.dataLayer || [];
  function gtag(){dataLayer.push(arguments);}
  gtag('js', new Date());

  gtag('config', 'G-TLMBHV8MEC');
</script>

    
    <?php echo $__env->yieldPushContent('prpend-style'); ?>
    <?php echo $__env->yieldPushContent('addon-style'); ?>

</head>

<body>

    
    <?php echo $__env->make('Frontend.Template.navbar', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>

    
    <?php echo $__env->yieldContent('content'); ?>
    <div class="fixed flex-row items-center bottom-4 right-4 z-50 md:bottom-10 md:right-10 flex ">
        <!-- Animated WhatsApp Button -->
        <div style="color:#fff;"
            class="slide-text whatsapp-button overflow-hidden shadow-2xl transition-all duration-500 ease-in-out bg-[#40C351] h-[40px] py-2 px-4 font-poppins text-white rounded-full mb-2">
            <h1 class="whatsapp-button-text ">ingin bertanya ? yuk di click !</h1>
        </div>

        <!-- WhatsApp Icon -->
        <a href="https://wa.me/6289504586704?text=Halo%20Admin%2C%20saya%20mau%20bertanya%20%0ASumber%20%3A%20<?php echo e(url()->current()); ?>" 
            target="_blank" rel="noopener noreferrer">
            <img src="<?php echo e(asset('images/logo/wa.jpg')); ?>" alt="WhatsApp" class="w-12 h-12 md:w-[70px] md:h-[70px]" >
        </a>

    </div>

    
    <?php echo $__env->make('Frontend.Template.footer', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>

    
    <?php echo $__env->yieldPushContent('prpend-script'); ?>
    <?php echo $__env->yieldPushContent('addon-script'); ?>
    </script>
    
    <script src="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.js"></script>
    
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.js"></script>
    <script src="./js/app.js"></script>
    <!-- disabled -->
  <script> document.addEventListener('contextmenu', function(event) { event.preventDefault(); alert('Right Click Disabled.'); }); </script>
</body>

</html>
<?php /**PATH C:\Users\User\Downloads\STEIYPAM\resources\views/Frontend/Layouts/app.blade.php ENDPATH**/ ?>