<?php $__env->startSection('title', 'Sejarah'); ?>


<?php $__env->startSection('content'); ?>
<br><br>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => 'Sejarah  '.e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia').'','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'Sejarah Singkat']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        

        <!-- Konten Teks -->
        <div data-aos="fade-up" class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px]">
            <p>
            Ide pendirian kampus AMIK Tri Dharma Pekanbaru dicetus pada bulan April 2002. Mereka sepakat untuk mendirikan Perguruan Tinggi yang bergerak di bidang komputer. Ide ini diwujudkan dengan terlebih dahulu membentuk Yayasan Perguruan Tinggi Riau. Setelah itu pada tahun yang sama, dilanjutkan dengan pengurusan izin pendirian Akademi Manjemen Informatika dan Komputer (AMIK) Tri Dharma Pekanbaru ke Dirjen Dikti di Jakarta. Saat itu izin yang diperoleh sesuai SK Mendiknas No: 249/D/O/2002 dengan 2 Program Studi yaitu :
                1. Manajemen Informatika
                2. Teknik Komputer 
            <br><br>
            AMIK Tri Dharma Pekanbaru mulai beroperasi menerima Mahasiswa baru pada Bulan September 2003, setelah terlebih dahulu melakukan sosialisasi kampus ke sekolah-sekolah yang ada di Provinsi Riau. Pada Tahun 2011, Program Studi Manajemen Informatika telah terakreditasi oleh Badan Akreditasi Nasional Perguruan Tinggi (BAN-PT) dengan No SK:005/BAN-PT/Ak-XI/Dpl-III/VIII/2011 yang berakhir pada tahun 2016. Lalu, pada tahun 2013, Program Studi Teknik Komputer juga telah terakreditasi oleh Badan Akreditasi Nasional Perguruan Tinggi (BAN-PT) dengan No SK: 209/SK/BAN-PT/Ak-XIII/Dpl-III/2013 yang berakhir pada tahun 2018. 
            <br><br>
            Kemudian, Pada tahun 2015, AMIK Tri Dharma Pekanbaru mengajukan Borang Akreditasi Institusi, dan Alhamdulillah juga telah terakreditasi oleh Badan Akreditasi Nasional Perguruan Tinggi (BAN-PT) dengan No SK:813/SK/BAN-PT/Akred/PT/VIII/2015 yang berakhir pada tahun 2020. Dan, Pada tahun 2016, Seiring dengan akan berakhirnya status akreditasi untuk Program Studi Manajemen Informatika, maka AMIK Tri Dharma Pekanbaru kembali mengajukan Borang Reakreditasi untuk Program Studi Manajemen Informatika pada bulan februari 2017, dan hasilnya status Akreditasi Program Studi Manajemen Informatika telah diperpanjang sampai tahun 2021 oleh BAN-PT dengan No.SK:0898/SK/BAN-PT/Akred/Dipl-III/2016. 
            <br><br>   </p>

            
        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">
                SEGERA DAFTAR
                </h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
            Bergabunglah bersama  <?php echo e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia'); ?> dan Bangun Wawasan, Bentuk Karakter, Jadilah Pembawa Perubahan!
        </p>
            <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/pendaftaran']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>DAFTAR SEKARANG <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /home/u645251767/domains/institutazzuhra.info/AZZUHRA/resources/views/Frontend/sejarah.blade.php ENDPATH**/ ?>