@section('title', 'Sejarah')

@extends('Frontend.Layouts.app2')
@section('content')
<br><br>
    <x-header-section-page title="Sejarah  {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}" breadcrumb-home="Home" breadcrumb-current="Sejarah Singkat" />

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        {{-- <img src="{{ asset('./images/sambutan/petinggi.png') }}" data-aos="fade-up" class=" mb-5 w-full" alt=""> --}}

        <!-- Konten Teks -->
        <div data-aos="fade-up" class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px]">
            <p class="text-justify" style="font-size: 14px;">
Sekolah Tinggi Ekonomi Islam (STEI) YPAM merupakan perguruan tinggi ekonomi syariah yang berdiri pada tahun 2025 dan berlokasi di Cipanas, Cianjur. Hadir dengan semangat membangun peradaban ekonomi berbasis nilai-nilai Islam, STEI YPAM memiliki visi menjadi inkubator pemimpin ekonomi global berbasis syariah.
<br><br>
Sebagai kampus baru yang progresif dan inklusif, STEI YPAM berkomitmen mencetak lulusan yang berintegritas, inovatif, serta berdaya saing internasional. Melalui kurikulum terpadu, pembelajaran berbasis praktik, dan lingkungan akademik yang kolaboratif, STEI YPAM siap menjadi pusat lahirnya pemimpin masa depan yang mampu memberikan kontribusi nyata bagi kemajuan ekonomi umat dan pembangunan global yang berkeadilan.
<br><br>
STEI YPAM berkomitmen untuk turut serta dalam pembangunan kualitas manusia melalui semangat keberlanjutan serta inovasi untuk menebar manfaat bagi ummat. Melalui semangat keberlanjutan, setiap langkah pengembangan diarahkan agar tidak hanya bermanfaat bagi hari ini, tetapi juga bagi generasi yang akan datang. STEI YPAM berkomitmen untuk turut berperan dalam inovasi yang berkelanjutan adalah kunci untuk menjaga keseimbangan antara kemajuan teknologi, kesejahteraan manusia, dan kelestarian alam.

            </p>

        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">
                SEGERA DAFTAR
                </h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
            Bergabunglah bersama  {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }} dan Bangun Wawasan, Bentuk Karakter, Jadilah Pembawa Perubahan!
        </p>
            <x-button url="/pendaftaran">DAFTAR SEKARANG</x-button>
        </div>
    </div>
@endsection
